OC.L10N.register(
    "spreed",
    {
    "a conversation" : "разговор",
    "(Duration %s)" : "(трајање %s)",
    "You attended a call with {user1}" : "Били сте на разговору са корисником {user1}",
    "_%n guest_::_%n guests_" : ["%n гост","%n госта","%n гостију"],
    "You attended a call with {user1} and {user2}" : "Били сте на разговору са корисницима {user1} и {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Били сте на разговору са корисницима {user1}, {user2} и {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Били сте на разговору са корисницима {user1}, {user2}, {user3} и {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Били сте на разговору са корисницима {user1}, {user2}, {user3}, {user4} и {user5}",
    "_%n other_::_%n others_" : ["%n остали","%n осталих","%n осталих"],
    "{actor} invited you to {call}" : "{actor} Вас је позвао у разговор {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Били сте позвани у собу на <strong>разговор</strong> или сте имали <strong>позив</strong>",
    "Other activities" : "Остале активности",
    "Talk" : "Разговор",
    "Guest" : "Гост",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Добродошли у Nextcloud Talk!\nУ овом разговору ћете бити обавештавани о новим функционалностима која постану доступна у апликацији Nextcloud Talk.",
    "## New in Talk %s" : "## Ново у Talk %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge и Сафари сада могу да се користе да учествујете у аудио и видео позивима",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Један-на-један разговори су сада стални и више не могу случајно да се претворе у групне разговоре. Такође, када један од учесника напусти разговор, разговор се више не брише аутоматски. Разговор се брише са сервера само ако га напусте оба учесника",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Сада можете да обавестите све учесника тако што објавите „@all“ у разговору",
    "- With the \"arrow-up\" key you can repost your last message" : "- Са „стрелицом горе“ можете поново објавити последњу поруку",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk сада има команде, пошаљите „/help“ као поруку у ћаскању да видите да ли је администратор подесио нешто",
    "- With projects you can create quick links between conversations, files and other items" : "- Уз помоћ пројеката можете да направите брзе везе између разговора, фајлова и других ставки",
    "- You can now mention guests in the chat" : "- Сада можете поменути госте у ћаскању",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Разговори сада могу да имају предсобље. То ће омогућити модераторима да приступе чету и позиву како би припремили састанак, док остали учесници и гости морају да чекају",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Сада директно можете да одговорите на поруке пружајући осталим корисницима о више контекста о чему се ради у вашој поруци",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Сада ће претрага разговора и учесника такође да филтрира ваше постојеће разговоре, тако да ће бити лакше да се пронађу претходни разговори",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Када је инсталирана апликација кругови, сада можете да у разговор додате произвољне групе корисника",
    "- Check out the new grid and call view" : "- Погледајте нове погледе мреже и позива",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Сада у разговор можете да отпремите или превучете и упустите фајлове директно са вашег уређаја",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Дељени фајлови се сада отварају директно у погледу чета апликацијама за преглед",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Сада можете да претражујете четове и поруке у обједињеној претрази у линији на врху",
    "- Spice up your messages with emojis from the emoji picker" : "- Зачините своје поруке емођијима из бирача емођија",
    "- You can now change your camera and microphone while being in a call" : "- Сада током разговора можете да проемените своју камеру и микрофон",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Дајте описом мало контекста својим разговорима и отворите их тако да пријављени корисници могу да их пронађу и да им се придруже",
    "- See a read status and send failed messages again" : "- Погледајте статус читања и поново пошаљите поруке које нису успешно послате",
    "- Raise your hand in a call with the R key" : "- Подигните руку у позиву тастером R",
    "- Join the same conversation and call from multiple devices" : "- Придружите се истом разговору и позиву са више уређаја",
    "- Send voice messages, share your location or contact details" : "- Шаљите гласовне поруке, делите своју локацију или контакт детаље",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Додајте групе у разговор, па ће нови чланови групе аутоматски да се додају као учесници",
    "- A preview of your audio and video is shown before joining a call" : "- Преглед вашег звука и видео слике се приказује пре приступања позиву",
    "- You can now blur your background in the newly designed call view" : "- Сада можете да замутите своју позадину у свеже дизајнираном погледу позива",
    "- Moderators can now assign general and individual permissions to participants" : "- Сада модератори могу да доделе опште и појединачне дозволе учесницима",
    "- You can now react to chat messages" : "- Сада можете да реагујете на чет поруке",
    "- In the sidebar you can now find an overview of the latest shared items" : "- На бочној траци сада можете пронаћи преглед најновијих дељених ставки",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Користите гласање да прикупите мишљења других или да се усагласите у вези са датумом",
    "- Configure an expiration time for chat messages" : "- Подесите време истека чет порука",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Започните позиве без обавештавања осталих у великим разговорима. Сада можете да шаљете појединачна обавештења након почетка разговора.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Шаљите чет поруке без обавештавања прималаца у скучају да порука није хитна.",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Сада је могуће да се емођији аутоматски довршавају куцањем „:”",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Повежите разне ствари користећи нови паметни бирач куцањем „/”",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Модератори сада могу да креирају сепарее (потребан је позадински механизам високих перформанси)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Разговори сада могу да се снимају (потребан је позадински механизам високих перформанси)",
    "- Conversations can now have an avatar or emoji as icon" : "- Разговори сада као икону могу да имају аватар или емођи",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Сада су у видео позивима уз замагљену позадину доступне су и виртуелне позадине",
    "- Reactions are now available during calls" : "- Сада су током позива доступне реакције",
    "- Typing indicators show which users are currently typing a message" : "- Индикатори куцања показују који корисници тренутно куцају поруку",
    "- Groups can now be mentioned in chats" : "- Сада у четовима могу да се помену групе",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Снимци позива се аутоматски транскрибују ако је регистрована апликација пружаоца услуге транскрибовања",
    "- Chat messages can be translated if a translation provider app is registered" : "- Чет поруке могу да се преведу ако је регистрована апликација пружаоца услуге превода",
    "- **Markdown** can now be used in _chat_ messages" : "- Сада у _чет_ порукама може да се користи **Markdown**",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- За имплементирање ботова су доступне веб куке. За више информација, погледајте документацију https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Поставите подсетник на чет поруку који вас касније подсећа на њу",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Употреба **Белешка за себе** разговора за узимање белешки и дељење информација између ваших уређаја",
    "- Captions allow to send a message with a file at the same time" : "- Наслови омогућавају слање поруке уз фајл у исто време",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- Видео говорника се сада види док се дели екран и реакције у позиву су анимиране",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Пријављени аутори и модератори сада у року од 6 сати могу да уређују поруке",
    "- Unsent message drafts are now saved in your browser" : "- Нацрти непослатих порука се сада чувају у вашем интернет прегледачу",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- Текст четовање са осталим Talk серверима сада може да се врши на федерисани начин",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Модератори сада могу да забране налоге и госте и да их тако спрече да поново приступе разговору",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- Сада се у разговорима приказују предстојећи позови из догађаја повезаних календара и замене ван-канцеларије",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- Позиви сада могу да се обаве на федерисани начин са осталим Talk серверима (потребан је позадински механизам високих перформанси)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Уводи се Nextcloud Talk десктоп клијент за Windows, macOS и Linux: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Резиме снимака разговора и непрочитаних порука у ћаскањима са Nextcloud Асистентом",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Побољшани састанци са препознавањем гостију који су позвани преко и-мејл адресе, увоз листи учесника, нацрти за гласања и преузимање листи учесника позива",
    "- Archive conversations to stay focused" : "- Архивирајте разговоре и останите фокусирани",
    "- Schedule a meeting into your calendar from within a conversation" : "- Закажите састанак у свој календар директно из разговора",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Претражујте поруке текућег разговора директно у десној бочној траци",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- Једним погледом видите још разговора помоћу нове збијене листе (укључите у Talk подешавањима)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- Разговори састанка сада синхронизују наслов и опис из календара и скривени су од филтера претраге све док нису близу почетка",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- Означите разговоре као осетљиве у подешавањима обавештења, тако да се у листи разговора и обавештењима сакрије садржај поруке",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- Ако желите да током „Не узнемиравај” статуса примате брза обавештења, означите разговоре као важне",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- Додајте остале учеснике у разговор један-на-један и тако у ходу креирајте групни позив",
    "- Use threads to keep your chat and discussions organized" : "- Користите низове да ваши четови и дискусије буду организовани",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- Сада је током позива доступна транскрипција уживо (потребна је live-transcription ExApp и позадински механизам високих перформанси)",
    "_All %n participant_::_All %n participants_" : ["%n учесник","%n учесника","Свих %n учесника"],
    "Talk updates ✅" : "Ажурирања Разговор апликације ✅",
    "Reaction deleted by author" : "Аутор је обрисао реакцију",
    "{actor} created the conversation" : "{actor} је креирао разговор",
    "You created the conversation" : "Направили сте разговор",
    "System created the conversation" : "Систем је креирао разговор",
    "An administrator created the conversation" : "Администратор је креирао разговор",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} је преименовао разговор са „%1$s“ на „%2$s“",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Преименовали сте разговор са „%1$s“ на „%2$s“",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Администратор је променио назив разговора са „%1$s” на „%2$s”",
    "{actor} set the description" : "{actor} је поставио опис",
    "You set the description" : "Поставили сте опис",
    "An administrator set the description" : "Администратор је поставио опис",
    "{actor} removed the description" : "{actor} је уклонио опис",
    "You removed the description" : "Уклонили сте опис",
    "An administrator removed the description" : "Администратор је уклонио опис",
    "You started a silent call" : "Започели сте утишани позив",
    "Outgoing silent call" : "Одлазни утишани позив",
    "{actor} started a silent call" : "{actor} је започео утишани позив",
    "Incoming silent call" : "Долазни утишани позив",
    "You started a call" : "Ви сте започели позив",
    "Outgoing call" : "Одлазни позив",
    "{actor} started a call" : "{actor} је започео/ла позив",
    "Incoming call" : "Долазни позив",
    "{actor} joined the call" : "{actor} се придружио позиву",
    "You joined the call" : "Придружили сте се позиву",
    "{actor} left the call" : "{actor} је напустио позив",
    "You left the call" : "Напустили сте позив",
    "{actor} unlocked the conversation" : "{actor} је откључао разговор",
    "You unlocked the conversation" : "Откључали сте разговор",
    "An administrator unlocked the conversation" : "Администратор је откључао разговор",
    "{actor} locked the conversation" : "{actor} је закључао разговор",
    "You locked the conversation" : "Закључали сте разговор",
    "An administrator locked the conversation" : "Администратор је закључао разговор",
    "{actor} limited the conversation to the current participants" : "{actor} је ограничио разговор на текуће учеснике",
    "You limited the conversation to the current participants" : "Ограничили сте разговор на текуће учеснике",
    "An administrator limited the conversation to the current participants" : "Администратор је ограничио разговор на текуће учеснике",
    "{actor} opened the conversation to registered users" : "{actor} је отворио разговор свим регистрованим корисницима",
    "You opened the conversation to registered users" : "Отворили сте разговор свим регистрованим корисницима",
    "An administrator opened the conversation to registered users" : "Администратор је отворио разговор свим регистрованим корисницима",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} је отворио разговор свим регистрованим корисницима и корисницима креиранима апликацијом Гости",
    "You opened the conversation to registered users and users created with the Guests app" : "Отворили сте разговор свим регистрованим корисницима и корисницима креиранима апликацијом Гости",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Администратор је отворио разговор свим регистрованим корисницима и корисницима креиранима апликацијом Гости",
    "The conversation is now open to everyone" : "Овај разговор је сада отворен свима",
    "{actor} opened the conversation to everyone" : "{actor} је отворио разговор свима",
    "You opened the conversation to everyone" : "Ви сте отворили разговор свима",
    "{actor} restricted the conversation to moderators" : "{actor} је ограничио разговор на модераторе",
    "You restricted the conversation to moderators" : "Ви сте ограничили разговор на модераторе",
    "{actor} started breakout rooms" : "{actor} је покренуо сепарее",
    "You started breakout rooms" : "Покренули сте сепарее",
    "{actor} stopped breakout rooms" : "{actor} је зауставио сепарее",
    "You stopped breakout rooms" : "Зауставили сте сепарее",
    "{actor} allowed guests" : "{actor} је дозволио госте",
    "You allowed guests" : "Ви сте дозволили госте",
    "An administrator allowed guests" : "Администратор је дозволио госте",
    "{actor} disallowed guests" : "{actor} је забранио госте",
    "You disallowed guests" : "Ви сте забранили госте",
    "An administrator disallowed guests" : "Администратор је забранио госте",
    "{actor} set a password" : "{actor} је поставио лозинку",
    "You set a password" : "Ви сте поставили лозинку",
    "An administrator set a password" : "Администратор је поставио лозинку",
    "{actor} removed the password" : "{actor} је уклонио лозинку",
    "You removed the password" : "Ви сте уклонили лозинку",
    "An administrator removed the password" : "Администратор је уклонио лозинку",
    "{actor} added {user}" : "{actor} је додао корисника {user}",
    "You joined the conversation" : "Придружили сте се разговору",
    "{actor} joined the conversation" : "{actor} се придружио разговору",
    "You added {user}" : "Ви сте додали корисника {user}",
    "{actor} added you" : "{actor} Вас је додао",
    "An administrator added you" : "Администратор вас је додао",
    "An administrator added {user}" : "Администратор је додао корисника {user}",
    "You left the conversation" : "Напустили сте разговор",
    "{actor} left the conversation" : "{actor} је напустио разговор",
    "{actor} removed {user}" : "{actor} је уклонио корисника {user}",
    "You removed {user}" : "Ви сте уклонили корисника {user}",
    "{actor} removed you" : "{actor} Вас је уклонио",
    "An administrator removed you" : "Администратор вас је уклонио",
    "An administrator removed {user}" : "Администратор је уклонио корисника {user}",
    "{actor} invited {federated_user}" : "{actor} је позвао корисника {federated_user}",
    "You invited {federated_user}" : "Позвали сте корисника {federated_user}",
    "You accepted the invitation" : "Прихватили сте позивницу",
    "{actor} invited you" : "{actor} вас је позвао",
    "An administrator invited you" : "Администратор вас је позвао",
    "An administrator invited {federated_user}" : "Администратор је позвао корисника {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} је прихватио позив",
    "{actor} removed {federated_user}" : "{actor} је уклонио корисника {federated_user}",
    "You removed {federated_user}" : "Уклонили сте корисника {federated_user}",
    "You declined the invitation" : "Одбили сте позивницу",
    "An administrator removed {federated_user}" : "Администратор је уклонио корисника {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} је одбио позив",
    "{actor} added group {group}" : "{actor} је додао групу {group}",
    "You added group {group}" : "Додали сте групу {group}",
    "An administrator added group {group}" : "Администратор је додао групу {group}",
    "{actor} removed group {group}" : "{actor} је уклонио групу {group}",
    "You removed group {group}" : "Уклонили сте групу {group}",
    "An administrator removed group {group}" : "Администратор је уклонио групу {group}",
    "{actor} added team {circle}" : "{actor} је додао тим {circle}",
    "You added team {circle}" : "Додали сте тим {circle}",
    "An administrator added team {circle}" : "Администратор је додао тим {circle}",
    "{actor} removed team {circle}" : "{actor} је уклонио тим {circle}",
    "You removed team {circle}" : "Уклонили сте тим {circle}",
    "An administrator removed team {circle}" : "Администратор је уклонио тим {circle}",
    "{actor} added {phone}" : "{actor} је додао {phone}",
    "You added {phone}" : "Додали сте {phone}",
    "An administrator added {phone}" : "Администратор је додао {phone}",
    "{actor} removed {phone}" : "{actor} је уклонио {phone}",
    "You removed {phone}" : "Уклонили сте {phone}",
    "An administrator removed {phone}" : "Администратор је уклонио {phone}",
    "{actor} promoted {user} to moderator" : "{actor} је унапредио корисника {user} у модератора",
    "You promoted {user} to moderator" : "Унапредили сте корисника {user} у модератора",
    "{actor} promoted you to moderator" : "{actor} Вас је унапредио у модератора",
    "An administrator promoted you to moderator" : "Администратор вас је унапредио у модератора",
    "An administrator promoted {user} to moderator" : "Администратор је унапредио корисника {user} у модератора",
    "{actor} demoted {user} from moderator" : "{actor} је скинуо улогу модератора кориснику {user}",
    "You demoted {user} from moderator" : "Скинули сте улогу модератора кориснику {user}",
    "{actor} demoted you from moderator" : "{actor} Вам је скинуо улогу модератора",
    "An administrator demoted you from moderator" : "Администратор вам је скинуо улогу модератора",
    "An administrator demoted {user} from moderator" : "Администратор је скинуо улогу модератора кориснику {user}",
    "{actor} shared a file which is no longer available" : "{actor} је поделио фајл који више није доступан",
    "You shared a file which is no longer available" : "Поделили сте фајл који више није доступан",
    "File shares are currently not supported in federated conversations" : "Дељења фајлова се тренутно не подржавају у федерисаним разговорима",
    "The shared location is malformed" : "Дељена локација није исправно формирана",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} је подесио Matterbridge да синхронизује овај чет са осталим четовима",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Подесили сте Matterbridge да синхронизује овај чет са осталим четовима",
    "{actor} created thread {title}" : "{actor} је креирао низ {title}",
    "You created thread {title}" : "Креирали сте низ {title}",
    "{actor} renamed thread {title}" : "{actor} је променио име низа {title}",
    "You renamed thread {title}" : "Променили сте име низа {title}",
    "{actor} updated the Matterbridge configuration" : "{actor} је ажурирао Matterbridge конфигурацију",
    "You updated the Matterbridge configuration" : "Ажурирали сте Matterbridge конфигурацију",
    "{actor} removed the Matterbridge configuration" : "{actor} је уклонио Matterbridge конфигурацију",
    "You removed the Matterbridge configuration" : "Уклонили сте Matterbridge конфигурацију",
    "{actor} started Matterbridge" : "{actor} је покренуо Matterbridge",
    "You started Matterbridge" : "Покренули сте Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} је зауставио Matterbridge",
    "You stopped Matterbridge" : "Зауставили сте Matterbridge",
    "{actor} deleted a message" : "{actor} је обрисао поруку",
    "You deleted a message" : "Обрисали сте поруку",
    "{actor} edited a message" : "{actor} је уредио поруку",
    "You edited a message" : "Уредили сте поруку",
    "{actor} pinned a message" : "{actor} је закачио поруку",
    "You pinned a message" : "Закачили сте поруку",
    "{actor} unpinned a message" : "{actor} је откачио поруку",
    "Message was automatically unpinned" : "Порука је аутоматски откачена",
    "You unpinned a message" : "Откачили сте поруку",
    "{actor} deleted a reaction" : "{actor} је обрисао реакцију",
    "You deleted a reaction" : "Обрисали сте реакцију",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Подесили сте да поруке истичу за %n недељу","Подесили сте да поруке истичу за %n недеље","Подесили сте да поруке истичу за %n недеља"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Подесили сте да поруке истичу за %n дан","Подесили сте да поруке истичу за %n дана","Подесили сте да поруке истичу за %n дана"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Подесили сте да поруке истичу за %n сат","Подесили сте да поруке истичу за %n сата","Подесили сте да поруке истичу за %n сати"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Подесили сте да поруке истичу за %n минут","Подесили сте да поруке истичу за %n минута","Подесили сте да поруке истичу за %n минута"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} је подесио да поруке истичу за %n недељу","{actor} је подесио да поруке истичу за %n недеље","{actor} је подесио да поруке истичу за %n недеља"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} је подесио да поруке истичу за %n дан","{actor} је подесио да поруке истичу за %n дана","{actor} је подесио да поруке истичу за %n дана"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} је подесио да поруке истичу за %n сат","{actor} је подесио да поруке истичу за %n сата","{actor} је подесио да поруке истичу за %n сати"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} је подесио да поруке истичу за %n минут","{actor} је подесио да поруке истичу за %n минута","{actor} је подесио да поруке истичу за %n минута"],
    "{actor} disabled message expiration" : "{actor} је искључио рок важења порука",
    "You disabled message expiration" : "Искључили сте рок важења порука",
    "{actor} cleared the history of the conversation" : "{actor} је обрисао историју разговора",
    "You cleared the history of the conversation" : "Обрисали сте историју разговора",
    "{actor} set the conversation picture" : "{actor} је поставио слику разговора",
    "You set the conversation picture" : "Поставили сте слику разговора",
    "{actor} removed the conversation picture" : "{actor} је уклонио слику разговора",
    "You removed the conversation picture" : "Уклонили сте слику разговора",
    "{actor} ended the poll {poll}" : "{actor} је затворио гласање {poll}",
    "You ended the poll {poll}" : "Затворили сте гласање {poll}",
    "{actor} started the video recording" : "{actor} је започео видео снимање",
    "You started the video recording" : "Започели сте видео снимање",
    "{actor} stopped the video recording" : "{actor} је зауставио видео снимање",
    "You stopped the video recording" : "Зауставили сте видео снимање",
    "{actor} started the audio recording" : "{actor} је започео снимање звука",
    "You started the audio recording" : "Започели сте снимање звука",
    "{actor} stopped the audio recording" : "{actor} је зауставио снимање звука",
    "You stopped the audio recording" : "Зауставили сте снимање звука",
    "The recording failed" : "Снимање није успело",
    "Someone voted on the poll {poll}" : "Неко је гласао у гласању {poll}",
    "Message deleted by author" : "Аутор је обрисао поруку",
    "Message deleted by {actor}" : "{actor} је обрисао поруку",
    "Message deleted by you" : "Обрисали сте поруку",
    "Deleted user" : "Обрисани корисник",
    "Unknown number" : "Непознати број",
    "Administration" : "Администрација",
    "System" : "Систем",
    "%s (guest)" : "%s (гост)",
    "Missed call" : "Пропуштени позив",
    "Unanswered call" : "Пропуштени позив",
    "Call ended (Duration {duration})" : "Позив је завршен (Трајање {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "Позив се завршио јер је достигнуто максимално трајање позива (Трајање {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} је завршио позив (Трајање {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["Завршен је позив са %n гостом јер је достигнуто максимално трајање позива (Трајање {duration})","Завршен је позив са %n госта јер је достигнуто максимално трајање позива (Трајање {duration})","Завршен је позив са %n гостију јер је достигнуто максимално трајање позива (Трајање {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Завршен је позив са %n гостом (трајање {duration})","Завршен је позив са %n госта (трајање {duration})","Завршен је позив са %n гостију (трајање {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} је завршио позив са %n гостом (Трајање {duration})","{actor} је завршио позив са %n госта (Трајање {duration})","{actor} је завршио позив са %n гостију (Трајање {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "Завршен је позив са корисником {user1} јер је достигнуто максимално трајање позива (Трајање {duration})",
    "Call with {user1} ended (Duration {duration})" : "Завршене је позив са корисником {user1} (Трајање {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} је завршио позив са корисником {user1} (Трајање {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "Завршене је позив са корисницима {user1} и {user2} јер је достигнуто максимално трајање позива (Трајање {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "Завршене је позив са корисницима {user1} и {user2} (трајање {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} је завршио позив са корисницима {user1} и {user2} (Трајање {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "Завршене је позив са корисницима {user1}, {user2} и {user3} јер је достигнуто максимално трајање позива (Трајање {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "Завршен је позив са корисницима {user1}, {user2} и {user3} (трајање {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} је завршио позив са корисницима {user1}, {user2} и {user3} (Трајање {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "Завршене је позив са корисницима {user1}, {user2}, {user3} и {user4} јер је достигнуто максимално трајање позива (Трајање {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "Завршен је позив са корисницима {user1}, {user2},  {user3} и {user4} (трајање {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} је завршио позив са корисницима {user1}, {user2}, {user3} и {user4} (Трајање {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "Завршене је позив са корисницима {user1}, {user2}, {user3}, {user4} и {user5} јер је достигнуто максимално трајање позива (Трајање {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "Завршен је позив са корисницима {user1}, {user2} {user3}, {user4} и {user5} (трајање {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} је завршио позив са корисницима {user1}, {user2}, {user3}, {user4} и {user5} (Трајање {duration})",
    "Message of {user} in {conversation}" : "Порука од {user} у {conversation}",
    "Message of {user}" : "Порука од {user}",
    "Message of a deleted user in {conversation}" : "Порука од обрисаног корисника у {conversation}",
    "Talk conversations" : "Talk разговори",
    "Call %s" : "Позив %s",
    "An error occurred. Please contact your administrator." : "Дошло је до грешке. Молимо вас да се обратите свом администратору.",
    "Storage quota exceeded" : "Прекорачена је квота за складиште",
    "File not found" : "Фајл није нађен",
    "File is not shared, or shared but not with the user" : "Фајл није дељен, или је дељен али не са корисником",
    "No account available to delete." : "Нема налога који треба да се обрише.",
    "Poll" : "Гласање",
    "Password needs to be set" : "Потребно је да се постави лозинка",
    "Uploading the file failed" : "Није успело отпремање фајла",
    "No image file provided" : "Није понуђен фајл слике",
    "File is too big" : "Фајл је превелики",
    "Invalid file provided" : "Дати фајл је неисправан",
    "Invalid image" : "Неисправна слика",
    "Unknown filetype" : "Непознат тип фајла",
    "Talk mentions" : "Talk спомињања",
    "More conversations" : "Још разговора",
    "Say hi to your friends and colleagues!" : "Поздравите Ваше пријатеље и колеге!",
    "No unread mentions" : "Нема непрочитаних помињања",
    "Call in progress" : "Позив је у току",
    "You were mentioned" : "Поменути сте",
    "Write to conversation" : "Пиши у разговор",
    "Writes event information into a conversation of your choice" : "Пише информације о догађају у разговор који изаберете",
    "Missing email field in header line" : "У линији заглавља недостаје поље и-мејла",
    "Following lines are invalid: %s" : "Нису исправне следеће линије: %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s вас је позвао у разговор „%2$s”.",
    "You were invited to conversation \"%s\"." : "Позвани сте у разговор „%s”.",
    "Conversation invitation" : "Позив за разговор",
    "Scheduled time" : "Заказано време",
    "Description" : "Опис",
    "You can also dial-in via phone with the following details" : "Такође можете да позовете телефоном користећи следеће детаље",
    "Dial-in information" : "Информације за позив",
    "Meeting ID" : "ID састанка",
    "Your PIN" : "Ваш PIN",
    "Click the button below to join the lobby now." : "Кликните на дугме испод да уђете у предсобље.",
    "Click the link below to join the lobby now." : "Кликните на линк испод да уђете у предсобље.",
    "Join lobby for \"%s\"" : "Уђите у предсобље за „%s”.",
    "Click the button below to join the conversation now." : "Кликните на дугме испод да уђете у разговор.",
    "Click the link below to join the conversation now." : "Кликните на линк испод да уђете у разговор.",
    "Join \"%s\"" : "Придружи се разговору  „%s”",
    "Meeting" : "Састанак",
    "Password request: %s" : "Захтев за лозинком: %s",
    "Private conversation" : "Приватни разговор",
    "Deleted user (%s)" : "Обрисани корисник (%s)",
    "Failed to upload call recording" : "Није успело отпремање снимка позива",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "Сервер за снимање није успео да опреми снимак позива {call}. Молимо вас да се обратите администрацији.",
    "Share to chat" : "Дели у чет",
    "Dismiss notification" : "Уклони обавештење",
    "Call recording now available" : "Сада је доступно снимање позива",
    "The recording for the call in {call} was uploaded to {file}." : "Снимак позива {call} је отпремљен у {file}.",
    "Transcript now available" : "Сада је доступан транскрипт",
    "The transcript for the call in {call} was uploaded to {file}." : "Транскрипт позива {call} је отпремљен у {file}.",
    "Failed to transcript call recording" : "Није успело креирање транскрипта снимка позива",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "Сервер није успео да креира транскрипт снимка позива {file} за позив {call}. Молимо вас да се обратите администрацији.",
    "Call summary now available" : "Сада је доступан резиме позива",
    "The summary for the call in {call} was uploaded to {file}." : "Резиме за позив у {call} је отпремљен у {file}.",
    "Failed to summarize call recording" : "Није успело резимирање снимка разговора",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "Сервер није успео да резимира снимак позива {file} за позив {call}. Молимо вас да се обратите администрацији.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "Позвао вас је {user1} да се придружите {roomName} на {remoteServer}",
    "Accept" : "Прихвати",
    "Decline" : "Одбиј",
    "{user1} invited you to a federated conversation" : "{user1} вас је позвао у здружени разговор",
    "Someone reacted" : "Неко је реаговао",
    "New message" : "Нова порука",
    "Reminder" : "Подсетник",
    "Someone mentioned you" : "Неко вас је поменуо",
    "Notification" : "Обавештење",
    "Someone reacted in a private conversation" : "Неко је реаговао у приватном разговору",
    "You received a message in a private conversation" : "Примили сте поруку у приватном разговору",
    "Reminder in a private conversation" : "Подсетник у приватном разговору",
    "Someone mentioned you in a private conversation" : "Неко вас је поменуо у приватном разговору",
    "Notification in a private conversation" : "Обавештење у приватном разговору",
    "Reminder: You in {call}" : "Подсетник: Ви у {call}",
    "Reminder: {user} in {call}" : "Подсетник: {user} у {call}",
    "Reminder: Deleted user in {call}" : "Подсетник: Обрисани корисник у {call}",
    "Reminder: {guest} (guest) in {call}" : "Подсетник: {guest} (гост) у {call}",
    "Reminder: Guest in {call}" : "Подсетник: Гост у {call}",
    "{user} reacted with {reaction}" : "{user} је реаговао са {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} је у {call} реаговао са {reaction}",
    "Deleted user reacted with {reaction} in {call}" : "Обрисано је корисник је у {call} реаговао са {reaction}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (гост) је {call} реаговао са {reaction}",
    "Guest reacted with {reaction} in {call}" : "Гост је {call} реаговао са {reaction}",
    "{user} in {call}" : "{user} у {call}",
    "Deleted user in {call}" : "Обрисани корисник у {call}",
    "{guest} (guest) in {call}" : "{guest} (гост) у {call}",
    "Guest in {call}" : "Гост у {call}",
    "{user} sent you a private message" : "{user} Вам је послао приватну поруку",
    "{user} sent a message in conversation {call}" : "{user} Вам је послао поруку у разговору: {call}",
    "A deleted user sent a message in conversation {call}" : "Обрисани корисник је послао поруку у разговору {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (гост) је послао поруку у разговору {call}",
    "A guest sent a message in conversation {call}" : "Гост је послао поруку у разговору {call}",
    "{user} replied to your private message" : "{user} је одговорио на Ваше приватне поруке",
    "{user} replied to your message in conversation {call}" : "{user} је одговорио на Ваше поруке у разговору {call}",
    "A deleted user replied to your message in conversation {call}" : "Обрисани корисник је одговорио на Вашу поруку у разговору {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (гост) је одговорио на Вашу поруку у разговору {call}",
    "A guest replied to your message in conversation {call}" : "Гост је одговорио на Вашу поруку у разговору {call}",
    "Reminder: You in private conversation {call}" : "Подсетник: Ви у приватном разговору {call}",
    "Reminder: A deleted user in private conversation {call}" : "Подсетник: Обрисани корисник у приватном разговору {call}",
    "Reminder: {user} in private conversation" : "Подсетник: {user} у приватном разговору",
    "Reminder: You in conversation {call}" : "Подсетник: Ви у разговору {call}",
    "Reminder: {user} in conversation {call}" : "Подсетник: {user} у разговору {call}",
    "Reminder: A deleted user in conversation {call}" : "Подсетник: Обрисани корисник у разговору {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Подсетник: {guest} (гост) у разговору {call}",
    "Reminder: A guest in conversation {call}" : "Подсетник: Гост у разговору {call}",
    "{user} reacted with {reaction} to your private message" : "{user} је реаговао са {reaction} на вашу приватну поруку",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} је реаговао са {reaction} на вашу поруку у разговору {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Обрисани корисник је реаговао са {reaction} на вашу поруку у разговору {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (гост) је реаговао са {reaction} на вашу поруку у разговору {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Гост је реаговао са {reaction} на вашу поруку у разговору {call}",
    "{user} mentioned you in a private conversation" : "{user} Вас је споменуо/ла у приватном разговору",
    "{user} mentioned group {group} in conversation {call}" : "{user} је поменуо групу {group} у разговору {call}",
    "{user} mentioned team {team} in conversation {call}" : "{user} је поменуо тим {team} у разговору {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} је поменуо све у разговору {call}",
    "{user} mentioned you in conversation {call}" : "{user} Вас је споменуо/ла у разговору: {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "Обрисани корисник је поменуо групу {group} у разговору {call}",
    "A deleted user mentioned team {team} in conversation {call}" : "Обрисани корисник је поменуо тим {team} у разговору {call}",
    "A deleted user mentioned everyone in conversation {call}" : "Обрисани корисник је поменуо све у разговору {call}",
    "A deleted user mentioned you in conversation {call}" : "Обрисани корисник Вас је споменуо/ла у разговору: {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (гост) је поменуо групу {group} у разговору {call}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (гост) је поменуо тим {team} у разговору {call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (гост) је поменуо све у разговору {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (гост) Вас је поменуо у разговору {call}",
    "A guest mentioned group {group} in conversation {call}" : "Гост је поменуо групу {group} у разговору {call}",
    "A guest mentioned team {team} in conversation {call}" : "Гост је поменуо тим {team} у разговору {call}",
    "A guest mentioned everyone in conversation {call}" : "Гост је поменуо све у разговору {call}",
    "A guest mentioned you in conversation {call}" : "Гост Вас је споменуо у разговору: {call}",
    "View message" : "Прикажи поруку",
    "Dismiss reminder" : "Одбаци подсетник",
    "View chat" : "Види ћаскање",
    "{user} invited you to a group conversation: {call}" : "{user} Вас је позвао/ла на групни разговор: {call}",
    "Join call" : "Придружи се разговору",
    "Answer call" : "Одговори на позив",
    "{user} would like to talk with you" : "{user} жели да прича са вама",
    "Call back" : "Узврати позив",
    "You missed a call from {user}" : "Пропустили сте позив од корисника {user}",
    "Accept call" : "Прихвати позив",
    "Incoming phone call from {call}" : "Долазни телефонски позив од {call}",
    "You missed a phone call from {call}" : "Пропустили сте телефонски позив од {call}",
    "A group call has started in {call}" : "Групни разговор је започет у {call}",
    "You missed a group call in {call}" : "Пропустили сте групни позив у разговору {call}",
    "{email} is requesting the password to access {file}" : "{email} је затражио лозинку да приступи фајлу {file}",
    "{email} tried to request the password to access {file}" : "{email} је покушао да затражи лозинку за приступ фајлу {file}",
    "Someone is requesting the password to access {file}" : "Неко је затражио лозинку да приступи фајлу {file}",
    "Someone tried to request the password to access {file}" : "Неко је покушао да затражи лозинку за приступ фајлу {file}",
    "Open settings" : "Отвори поставке",
    "Hosted signaling server added" : "Додат је хостовани сервер за сигнализацију",
    "The hosted signaling server is now configured and will be used." : "Хостовани сервер за синализирање је сада подешен и користиће се.",
    "Hosted signaling server removed" : "Уклоњен је хостовани сервер за сигнализацију",
    "The hosted signaling server was removed and will not be used anymore." : "Хостовани сервер за синализирање је уклоњен и више се неће користити.",
    "Hosted signaling server changed" : "Промењен је хостовани сервер за сигнализацију",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Налог хостованог сервера за сигнализирање је променио статус са „{oldstatus}” на „{newstatus}”.",
    "pending" : "на чекању",
    "active" : "активна",
    "expired" : "истекла",
    "blocked" : "блокирана",
    "error" : "грешка",
    "The certificate of {host} expires in {days} days" : "Важење сертификата за {host} истиче за {days} дана",
    "The certificate of {host} expired" : "Важење сертификата за {host} истекло",
    "Contact via Talk" : "Контактирај преко Talk",
    "Open Talk" : "Отвори Talk",
    "Default" : "Подразумевано",
    "Presentation" : "Презентација",
    "Conversations" : "Разговори",
    "Messages in current conversation" : "Поруке у текућем разговору",
    "{user}" : "{user}",
    "Messages" : "Поруке",
    "{user} in {conversation}" : "{user} у {conversation}",
    "Messages in other conversations" : "Поруке у осталим разговорима",
    "One-to-one rooms always need to show the other users avatar" : "Један-на-један собе увек морају да прикажу аватаре осталих корисника",
    "Invalid emoji character" : "Неисправан емођи карактер",
    "Invalid background color" : "Неисправна боја позадине",
    "Avatar image is not square" : "Слика аватара није квадратна",
    "Room {number}" : "Соба {number}",
    "Favorites" : "Омиљене",
    "Other" : "Остало",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Није успео захтев за пробу јер пробни сервер није доступан. Молимо вас да покушате касније.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Постоји проблем са потврђивањем ове инстанце. Можда није доступна споља, па не може да се провери њен URL.",
    "Something unexpected happened." : "Десило се нешто неочекивано.",
    "The URL is invalid." : "URL није исправан.",
    "An HTTPS URL is required." : "Захтева се HTTPS URL.",
    "The email address is invalid." : "И-мејл адреса није исправна.",
    "The language is invalid." : "Језик је неисправан.",
    "The country is invalid." : "Земља је неисправна.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Постоји проблем за захтевом за пробу. Молимо вас да погледате своје дневнике за више информација.",
    "Too many requests are send from your servers address. Please try again later." : "Са адресе вашег сервера се шаље превише захтева. Молимо вас да покушате поново касније.",
    "There is already a trial registered for this Nextcloud instance." : "Већ постоји проба регистрована за ову Nextcloud инстанцу.",
    "Something unexpected happened. Please try again later." : "Десило се нешто неочекивано. Молимо вас да покушате поново касније.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Није успео захтев за пробу јер се пробни сервер понаша погрешно. Молимо вас да покушате касније.",
    "Trial requested but failed to get account information. Please check back later." : "Проба је захтевана али није успело добављање информације о налогу. Молимо вас да поново проверите касније.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Постоји проблем са потрврђивањем овог разлога. Можда није доступан споља, па не може да се провери њен URL.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Није успело добављање информација о налогу јер се пробни сервер понаша погрешно. Молимо вас да покушате касније.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Постоји проблем за добављањем информација о налогу. Молимо вас да погледате своје дневнике за више информација.",
    "There is no such account registered." : "Такав налог није регистрован.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Није успело добављање информација о налогу јер пробни сервер није доступан. Молимо вас да покушате касније.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Није успело брисање налога хостованог сервера за сигнализирање. Молимо вас да поново проверите касније.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Није успело брисање налога јер се пробни сервер понаша погрешно. Молимо вас да покушате касније.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Постоји проблем за брисањем налога. Молимо вас да погледате своје дневнике за више информација.",
    "Too many requests are sent from your servers address. Please try again later." : "Са адресе вашег сервера се шаље превише захтева. Молимо вас да покушате поново касније.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Није успело брисање налога јер пробни сервер није доступан. Молимо вас да покушате касније.",
    "Note to self" : "Белешка самом себи",
    "A place for your private notes, thoughts and ideas" : "Место за ваше приватне белешке, мисли и идеје",
    "Transcript is AI generated and may contain mistakes" : "Транскрипт је генерисала AI и може да садржи грешке",
    "Summary is AI generated and may contain mistakes" : "Резиме је генерисала AI и може да садржи грешке",
    "Let's get started!" : "Хајде да почнемо!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Talk** је сигурна платфора за комуникацију која је хостована на вашој инфраструктури и која се неприметно интегрише у Nextcloud екосистем.\n\n#### Кључне могућности апликације Nextcloud Talk:\n\n* Чет и размена порука у приватним и групним ћаскањима\n* Гласовни и видео позиви\n* Дељење фајлова и интеграција са осталим Nextcloud апликацијама\n* Прилагодљива подешавања разговора, модерисање и контрола приватности\n* Веб, десктоп и мобилна верзија (iOS и Android)\n* Приватна и безбедна комуникација\n\n Сазнајте више у [корисничкој документацији](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Добродошли у Nextcloud Talk\n\nNextcloud Talk је приватна и моћна апликација за размену порука која се интегрише са Nextcloud. Чет у приватним и групним разговорима, сарадња преко гласовних и видео позива, организација вебинара и догађаја, прилагођавање ваших разговора и још доста тога.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 Форматирајте текст и креирајте обогаћене поруке\n\nУ Nextcloud Talk можете да користите Markdown синтаксу за означавање порука које шаљете. На пример, примените **подебљано** или *курзив* форматирање, или `истакните текст као изворни кôд`. Можете чак да креирате и табеле или да додате наслове у свој текст.\n\nТреба да исправите грешку у куцању или да измените форматирање? Уредите своју поруку кликом на „Уреди поруку” у менију поруке.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 Додајте прилоге и линкове\n\nКористећи дугме „+” можете да додате фајлове из свог Nextcloud Hub. Делите ставке из Фајлова и разних Nextcloud апликација. Неке апликације чак подржавају и интерактивне виџете, на пример, апликација Текст.",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 Нека разговор тече: помените кориснике, реагујте на поруке и још тога\n\nУ разговору можете да поменете све користећи %s или одређене учеснике тако што откуцате „@” па из листе изаберете њихово име.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Можете да одговорите на поруке, да их проследите у друга ћаскања и другим особама, или да копирате садржај поруке.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ Урадите више употребом Паметног бирача\n\nКада желите да отворите Паметни бирач, просто откуцајте „/” или идите на „+” мени, и тако прикачите разни садржај у своје поруке. Паметни бирач можете подесити тако да буде у могућности да додаје ставке из Nextcloud апликација, GIF-ове, локације на мапи, AI генерисани садржај и још много тога.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ Управљајте подешавањима разговора\n\nУ менију разговора можете да приступите разним подешавањима којима управљате својим разговорима, као што су:\n* Уређивање информација о разговору\n* Управљање обавештењима\n* Примена бројних правила модерације\n* Подешавање права приступа и безбедности\n* Укључивање ботова\n* и још више!",
    "Andorra" : "Андора",
    "United Arab Emirates" : "Уједињени Арапски Емирати",
    "Afghanistan" : "Авганистан",
    "Antigua and Barbuda" : "Антигва и Барбуда",
    "Anguilla" : "Ангвила",
    "Albania" : "Албанија",
    "Armenia" : "Јерменија",
    "Angola" : "Ангола",
    "Antarctica" : "Антарктик",
    "Argentina" : "Аргентина",
    "American Samoa" : "Америчка Самоа",
    "Austria" : "Аустрија",
    "Australia" : "Аустралија",
    "Aruba" : "Аруба",
    "Åland Islands" : "Оландска острва",
    "Azerbaijan" : "Азербејџан",
    "Bosnia and Herzegovina" : "Босна и Херцеговина",
    "Barbados" : "Барбадос",
    "Bangladesh" : "Бангладеш",
    "Belgium" : "Белгија",
    "Burkina Faso" : "Буркина Фасо",
    "Bulgaria" : "Бугарска",
    "Bahrain" : "Бахреин",
    "Burundi" : "Бурунди",
    "Benin" : "Бенин",
    "Saint Barthélemy" : "Сент Бартелеми",
    "Bermuda" : "Бермуда",
    "Brunei Darussalam" : "Брунеј",
    "Bolivia, Plurinational State of" : "Боливија, Вишенационална држава",
    "Bonaire, Sint Eustatius and Saba" : "Карипска Холандија",
    "Brazil" : "Бразил",
    "Bahamas" : "Бахами",
    "Bhutan" : "Бутан",
    "Bouvet Island" : "Буве",
    "Botswana" : "Боцвана",
    "Belarus" : "Белорусија",
    "Belize" : "Белизе",
    "Canada" : "Канада",
    "Cocos (Keeling) Islands" : "Кокосова (Килинг) Острва",
    "Congo, the Democratic Republic of the" : "Конго, Демократска Република",
    "Central African Republic" : "Централноафричка Република",
    "Congo" : "Конго",
    "Switzerland" : "Швајцарска",
    "Côte d'Ivoire" : "Обала Слоноваче",
    "Cook Islands" : "Кукова Острва",
    "Chile" : "Чиле",
    "Cameroon" : "Камерун",
    "China" : "Кина",
    "Colombia" : "Колумбија",
    "Costa Rica" : "Костарика",
    "Cuba" : "Куба",
    "Cabo Verde" : "Зеленортска острва",
    "Curaçao" : "Курасао",
    "Christmas Island" : "Ускршња острва",
    "Cyprus" : "Кипар",
    "Czechia" : "Чешка",
    "Germany" : "Немачка",
    "Djibouti" : "Џибути",
    "Denmark" : "Данска",
    "Dominica" : "Доминика",
    "Dominican Republic" : "Доминиканска Република",
    "Algeria" : "Алжир",
    "Ecuador" : "Еквадор",
    "Estonia" : "Естонија",
    "Egypt" : "Египат",
    "Western Sahara" : "Западна Сахара",
    "Eritrea" : "Еритреја",
    "Spain" : "Шпанија",
    "Ethiopia" : "Етиопија",
    "Finland" : "Финска",
    "Fiji" : "Фиџи",
    "Falkland Islands (Malvinas)" : "Фолкландска (Малвинска) острва",
    "Micronesia, Federated States of" : "Микронезије, Савезне државе",
    "Faroe Islands" : "Фарска Острва",
    "France" : "Француска",
    "Gabon" : "Габон",
    "United Kingdom of Great Britain and Northern Ireland" : "Уједињено Краљевство",
    "Grenada" : "Гренада",
    "Georgia" : "Грузија",
    "French Guiana" : "Француска Гвајана",
    "Guernsey" : "Гернзи",
    "Ghana" : "Гана",
    "Gibraltar" : "Гибралтар",
    "Greenland" : "Гренланд",
    "Gambia" : "Гамбија",
    "Guinea" : "Гвинеја",
    "Guadeloupe" : "Гвадалупе",
    "Equatorial Guinea" : "Екваторијална Гвинеја",
    "Greece" : "Грчка",
    "South Georgia and the South Sandwich Islands" : "Јужна Џорџија и Јужна Сендвичка острва",
    "Guatemala" : "Гватемала",
    "Guam" : "Гвам",
    "Guinea-Bissau" : "Гвинеја Бисао",
    "Guyana" : "Гвајана",
    "Hong Kong" : "Хонг Конг",
    "Heard Island and McDonald Islands" : "Острво Херд и острва Макдоналд",
    "Honduras" : "Хондурас",
    "Croatia" : "Хрватска",
    "Haiti" : "Хаити",
    "Hungary" : "Мађарска",
    "Indonesia" : "Индонезија",
    "Ireland" : "Ирска",
    "Israel" : "Израел",
    "Isle of Man" : "Острво Мен",
    "India" : "Индија",
    "British Indian Ocean Territory" : "Британска територија Индијског океана",
    "Iraq" : "Ирак",
    "Iran, Islamic Republic of" : "Иран, Исламска република",
    "Iceland" : "Исланд",
    "Italy" : "Италија",
    "Jersey" : "Џерзи",
    "Jamaica" : "Јамајка",
    "Jordan" : "Јордан",
    "Japan" : "Јапан",
    "Kenya" : "Кенија",
    "Kyrgyzstan" : "Киргистан",
    "Cambodia" : "Камбоџа",
    "Kiribati" : "Кирибати",
    "Comoros" : "Комори",
    "Saint Kitts and Nevis" : "Сент Китс и Невис",
    "Korea, Democratic People's Republic of" : "Кореја, Демократска народна република",
    "Korea, Republic of" : "Кореја, Република",
    "Kuwait" : "Кувајт",
    "Cayman Islands" : "Кајманска острва",
    "Kazakhstan" : "Казахстан",
    "Lao People's Democratic Republic" : "Лаоска Народна Демократска Република",
    "Lebanon" : "Либан",
    "Saint Lucia" : "Света Луција",
    "Liechtenstein" : "Лихтенштајн",
    "Sri Lanka" : "Шри Ланка",
    "Liberia" : "Либерија",
    "Lesotho" : "Лесото",
    "Lithuania" : "Литванија",
    "Luxembourg" : "Луксембург",
    "Latvia" : "Летонија",
    "Libya" : "Либија",
    "Morocco" : "Мароко",
    "Monaco" : "Монако",
    "Moldova, Republic of" : "Молдавија, Република",
    "Montenegro" : "Црна Гора",
    "Saint Martin (French part)" : "Свети Мартин (Француска)",
    "Madagascar" : "Мадагаскар",
    "Marshall Islands" : "Маршалска Острва",
    "North Macedonia" : "Северна Македонија",
    "Mali" : "Мали",
    "Myanmar" : "Мјанмар",
    "Mongolia" : "Монголија",
    "Macao" : "Макао",
    "Northern Mariana Islands" : "Северна Маријанска Острва",
    "Martinique" : "Мартиник",
    "Mauritania" : "Мауританија",
    "Montserrat" : "Монтсерат",
    "Malta" : "Малта",
    "Mauritius" : "Маурицијус",
    "Maldives" : "Малдиви",
    "Malawi" : "Малави",
    "Mexico" : "Мексико",
    "Malaysia" : "Малезија",
    "Mozambique" : "Мозамбик",
    "Namibia" : "Намибија",
    "New Caledonia" : "Нова Каледонија",
    "Niger" : "Нигер",
    "Norfolk Island" : "Острво Норфок",
    "Nigeria" : "Нигерија",
    "Nicaragua" : "Никарагва",
    "Netherlands" : "Холандија",
    "Norway" : "Норвешка",
    "Nepal" : "Непал",
    "Nauru" : "Науру",
    "Niue" : "Нијуе",
    "New Zealand" : "Нови Зеланд",
    "Oman" : "Оман",
    "Panama" : "Панама",
    "Peru" : "Перу",
    "French Polynesia" : "Француска Полинезија",
    "Papua New Guinea" : "Папуа Нова Гвинеја",
    "Philippines" : "Филипини",
    "Pakistan" : "Пакистан",
    "Poland" : "Пољска",
    "Saint Pierre and Miquelon" : "Сен Пјер и Микелон",
    "Pitcairn" : "Питкерн",
    "Puerto Rico" : "Порторико",
    "Palestine, State of" : "Држава Палестина",
    "Portugal" : "Португалија",
    "Palau" : "Палау",
    "Paraguay" : "Парагвај",
    "Qatar" : "Катар",
    "Réunion" : "Реинион",
    "Romania" : "Румунија",
    "Serbia" : "Србија",
    "Russian Federation" : "Руска Федерација",
    "Rwanda" : "Руанда",
    "Saudi Arabia" : "Саудијска Арабија",
    "Solomon Islands" : "Соломонска Острва",
    "Seychelles" : "Сејшели",
    "Sudan" : "Судан",
    "Sweden" : "Шведска",
    "Singapore" : "Сингапур",
    "Saint Helena, Ascension and Tristan da Cunha" : "Света Јелена, Асенсион и Тристан да Куња",
    "Slovenia" : "Словенија",
    "Svalbard and Jan Mayen" : "Свалбард и Јан Мајен острва",
    "Slovakia" : "Словачка",
    "Sierra Leone" : "Сијера Леоне",
    "San Marino" : "Сан Марино",
    "Senegal" : "Сенегал",
    "Somalia" : "Сомалија",
    "Suriname" : "Суринам",
    "South Sudan" : "Јужни Судан",
    "Sao Tome and Principe" : "Сао Томе и Принципе",
    "El Salvador" : "Ел Салвадор",
    "Sint Maarten (Dutch part)" : "Свети Мартин (Холандија)",
    "Syrian Arab Republic" : "Сирија",
    "Eswatini" : "Есватини",
    "Turks and Caicos Islands" : "Теркс и Кејкос",
    "Chad" : "Чад",
    "French Southern Territories" : "Француске јужне и антарктичке земље",
    "Togo" : "Того",
    "Thailand" : "Тајланд",
    "Tajikistan" : "Таџикистан",
    "Tokelau" : "Токелау",
    "Timor-Leste" : "Источни Тимор",
    "Turkmenistan" : "Туркменистан",
    "Tunisia" : "Тунис",
    "Tonga" : "Тонга",
    "Turkey" : "Турска",
    "Trinidad and Tobago" : "Тринидад и Тобаго",
    "Tuvalu" : "Тувалу",
    "Taiwan, Province of China" : "Тајван, провинција Кине",
    "Tanzania, United Republic of" : "Танзанија",
    "Ukraine" : "Украјина",
    "Uganda" : "Уганда",
    "United States Minor Outlying Islands" : "Мала спољна острва Сједињених Држава",
    "United States of America" : "Сједињене Америчке Државе",
    "Uruguay" : "Уругвај",
    "Uzbekistan" : "Узбекистан",
    "Holy See" : "Света столица",
    "Saint Vincent and the Grenadines" : "Сент Винсент и Гренадини",
    "Venezuela, Bolivarian Republic of" : "Венецуела, Боливарска република",
    "Virgin Islands, British" : "Девичанска Острва, Британска",
    "Virgin Islands, U.S." : "Девичанска Острва, Америчка",
    "Viet Nam" : "Вијетнам",
    "Vanuatu" : "Вануату",
    "Wallis and Futuna" : "Валис и Футуна",
    "Samoa" : "Самоа",
    "Yemen" : "Јемен",
    "Mayotte" : "Мајот",
    "South Africa" : "Јужноафричка република",
    "Zambia" : "Замбија",
    "Zimbabwe" : "Зимбабве",
    "Background blur" : "Замућење позадине",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "Није могла да се провери подршка за учитавање WASM фајлова. Молимо вас да ручно проверите да ли ваш веб сервер сервира `.wasm` фајлове.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Ваш веб сервер није исправно подешен да испоручи .wasm фајлове. Ово је обично проблем са Nginx конфигурацијом. За замућење позадине је неопходно да се направе измене у конфигурацији како би могли да се испоруче и .wasm фајлови. Упоредите своју Nginx конфигурацију са препорученом конфигурацијом у нашој документацији.",
    "Talk configuration values" : "Вредности Talk конфигурације",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "Форсирање трајања разговора се подржава само на системима са cron. Молимо вас да укључите системски cron или да уклоните `max_call_duration` конфигурацију.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "Мале `max_call_duration` вредности (тренутно је постављено на %d) не могу да се форсирају услед техничких ограничења. Позадински посао се извршава само сваких пет минута, тако да ово радите на сопствени ризик.",
    "Federation" : "Здруживање",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Када је укључена Talk федерација, снажно се препоручује конфигурисање „memcache.locking”.",
    "High-performance backend" : "Позадински механизам високих перформанси",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "Није подешен ниједан позадински механизам високих перформанси - Извршавање Nextcloud Talk апликације без позадинског механизма високих перформанси има смисла само за врло мале позиве (2-3 учесника максимално). Молимо вас да подесите позадински механизам високих перформанси јер се тако обезбеђује да позиви са више учесника раде без проблема.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "Извршавање „conversation_cluster” режима позадинског механизма високих перформанси је застарело и неће се подржавати у наредној верзији. Позадински механизам високих перформанси у данашње време подржава право груписање, тако да би то требало да се користи.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "Дефинисање више позадинских механизама високих перформанси је застарело и неће се подржавати у наредној верзији. Уместо тога, требало би да се подеси балансер оптерећења заједно са груписаним серверима за сигнализацију и да се конфигурише у подешавањима Talk апликације.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "Сачувани јавни кључ за алгоритам који се користи %1$s не одговара сачуваном приватном кључу. Покрените %2$s да поправите проблем.",
    "High-performance backend not configured correctly. Run %s for details." : "Позадински механизам високих перформанси није исправно подешен. Покрените %s за детаље.",
    "High-performance backend not configured correctly" : "Позадински механизам високих перформанси није исправно подешен",
    "Error: Cannot connect to server" : "Грешка: не може да се успостави веза са сервером",
    "Error: Server did not respond with proper JSON" : "Error: сервер није одговорио са исправним JSON",
    "Error: Certificate expired" : "Грешка: важење сертификата је истекло",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Грешка: системскко време Nextcloud сервера и сервера позадинског механизма високе перформансе. Молимо вас да обезбедите везу оба сервера са сервером тачног времена, или ручно ускладите време на њима.",
    "Could not get version" : "Не може да се добави верзија",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Грешка: Верзија која се извршава: {version}; потребно је да се сервер ажурира да би био компатибилан са овом верзијом апликације Talk",
    "Error: Server responded with: {error}" : "Error: сервер је одговорио са: {error}",
    "Error: Unknown error occurred" : "Error: дошло је до непознате грешке",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Упозорење: Верзија која се извршава: {version}; Сервер не подржава све могућности ове Talk верзије, недостају функције: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "Када се Nextcloud Talk користи заједно са позадинским механизмом високих перформанси, снажно се препоручује да се подеси кеширање меморије.",
    "Client Push" : "Client Push",
    "Recording backend" : "Позадински механизам са снимање",
    "Using the recording backend requires a High-performance backend." : "Када се користи позадински механизам за снимање, потребно је да се користи и позадински механизам високих перформанси.",
    "No recording backend configured" : "Није подешен ниједан позадински механизам за снимање",
    "SIP configuration" : "SIP конфигурација",
    "Using the SIP functionality requires a High-performance backend." : "Употреба SIP функционалности захтева коришћење позадинског механизма високих перформанси.",
    "No SIP backend configured" : "Није подешен ниједан SIP позадински механизам",
    "Invalid date, date format must be YYYY-MM-DD" : "Неисправан датим, формат датума мора бити ГГГГ-ММ-ДД",
    "Conversation not found" : "Разговор није нађен",
    "Path is already shared with this conversation" : "Путања се већ дели у овом разговору",
    "Chat, video & audio-conferencing using WebRTC" : "Ћаскање, аудио & видео конференцијски позиви преко WebRTC-а",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Чет, видео & аудио конференције помоћу WebRTC\n\n* 💬 **Чет** Nextcloud Talk се испоручује са једноставним текст четом који вам омогућава да делите или отпремате фајлове из ваше апликације Nextcloud Фајлови или са локалног уређаја, као и да помињете остале учеснике.\n* 👥 **Приватни, групни, јавни и лозинком заштићени позиви!** Позовите некога, целу групу, или пошаљите јавни линк да бисте позвали у позив.\n* 🌐 **Федерисани четови** Четујте са осталим Nextcloud корисницима на њиховим серверима\n* 💻 **Дељење екрана!** Делите свој екран са учесницима позива.\n* 🚀 **Интеграција са осталим Nextcloud апликацијама** као што су Фајлови, Календар, Статус корисника, Контролна табла, Ток, Мапе, Паметни бирач, Контакти, Шпил и многе друге.\n* 🌉 **Синхронизација са осталим чет решењима** Пошто је [Matterbridge](https://github.com/42wim/matterbridge/) интегрисан у Talk, једноставно можете да синхронизујте велики број осталих чет решења у Nextcloud Talk и обрнуто.",
    "Leave call" : "Напусти разговор",
    "Navigating away from the page will leave the call in {conversation}" : "Одлазак са странице ће оставити позив у {conversation}",
    "Stay in call" : "Остани у позиву",
    "Error occurred when getting the conversation information" : "Дошло је до грешке током преузимања информација о разговору",
    "Duplicate session" : "Дупликат сесија",
    "Discuss this file" : "Причај о овом фајлу",
    "Loading …" : "Учитавање…",
    "Share this file with others to discuss it" : "Дели овај фајл са другима да причаш о њему",
    "Join conversation" : "Укључи се у разговор",
    "Share this file" : "Подели овај фајл",
    "Error occurred when joining the conversation" : "Дошло је до грешке током приступања разговору",
    "This conversation is password-protected." : "Овај разговор је заштићен лозинком.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Приметили смо више неисправних покушаја пријава са ваше IP адресе. Зато ће ваша следећа пријава бити могућа тек за 30 секунди.",
    "The password is wrong. Try again." : "Лозинка је погрешна. Покушајте поново.",
    "Password" : "Лозинка",
    "Submit" : "Пошаљи",
    "Error requesting the password." : "Грешка приликом захтевања лозинке.",
    "Request password" : "Захтевај лозинку",
    "This conversation has ended" : "Разговор је завршен",
    "Close Talk sidebar" : "Затвори Talk бочну траку",
    "Open Talk sidebar" : "Отвори Talk бочну траку",
    "Everyone" : "Сви",
    "Users and moderators" : "Корисници и модератори",
    "Moderators only" : "Само модератори",
    "Disable calls" : "Искључи позиве",
    "Save changes" : "Сними измене",
    "Saving …" : "Чувам…",
    "Saved!" : "Сачувано!",
    "Limit to groups" : "Ограничи на групе",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Када се означи бар једна група, само људи из излистаних група ће бити део разговора.",
    "Guests can still join public conversations." : "Гости и даље могу да се придруже јавним разговорима.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Корисници који више не могу да користе Talk ће и даље бити наведени као учесници у њиховим претходним разговорима и чуваће се и њихове поруке.",
    "Limit using Talk" : "Ограничи коришћење talk",
    "Limit creating a public and group conversation" : "Ограничи креирање јавних и групних разговора",
    "Limit creating conversations" : "Ограничи креирање разговора",
    "Limit starting a call" : "Ограничи започињање позива",
    "Limit starting calls" : "Limit starting позива",
    "When a call has started, everyone with access to the conversation can join the call." : "Када је позив започет, свако са приступом разговору може да се придружи и позиву.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "На овом серверу су инсталирани следећи ботови. У документацији можете пронаћи детаље како да {linkstart1}изградите сопствени бот{linkend} или {linkstart2}листу ботова{linkend} које можете да укључите на серверу.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "На овом серверу није инсталиран ниједан бот. У документацији можете пронаћи детаље како да {linkstart1}изградите сопствени бот{linkend} или {linkstart2}листу ботова{linkend} које можете да укључите на серверу.",
    "Description is not provided" : "Није достављена документација",
    "Locked for moderators" : "Закључано за модераторе",
    "Enabled" : "укључено",
    "Disabled" : "Искључено",
    "Bots settings" : "Оба подешавања",
    "State" : "Стање",
    "Name" : "Име",
    "Last error" : "Последња грешка",
    "Total errors count" : "Укупан број грешака",
    "Find more bots" : "Пронађи још ботова",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "Сервери којима се верује мегу да се подесе на {linkstart}страници Подешавања дељења{linkend}.",
    "Beta" : "Бета",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "Здружени четови и позиви већ функционишу. Обрада прилога ће доћи у будућој верзији.",
    "Enable Federation in Talk app" : "Укључи Заједницу у Talk апликацији",
    "Permissions" : "Дозволе",
    "Allow users to be invited to federated conversations" : "Дозволи да се коринисници позивају у федерисане разговоре",
    "Allow users to invite federated users into conversation" : "Дозволи да корисници позивају федерисане кориснике у разговор",
    "Only allow to federate with trusted servers" : "Дозволи федерисање само са серверима којима се верује",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "Када се означи бар једна група, само ће људи из наведених група моћи да позивају федерисане кориснике у разговор.",
    "Groups allowed to invite federated users" : "Групе којима је дозвољено да позивају федерисане кориснике",
    "Select groups …" : "Изаберите групе…",
    "All messages" : "Све поруке",
    "@-mentions only" : "Само @-помињања",
    "Off" : "Искључена",
    "General settings" : "Опште поставке",
    "Default notification settings" : "Подразумевана подешавања обавештења",
    "Default group notification" : "Подразумевана групна обавештења",
    "Default group notification for new groups" : "Подразумевана групна обавештења за нове групе",
    "Integration into other apps" : "Интеграција у друге апликације",
    "Allow conversations on files" : "Дозволи разговоре у фајловима",
    "Allow conversations on public shares for files" : "Дозволи разговоре на јавним дељењима фајлова",
    "End-to-end encrypted calls" : "Позиви шифровани с-краја-на-крај",
    "Enable encryption" : "Укључи шифровање",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "Позиви шифровани с-краја-на-крај са подешеним SIP мостом захтевају употребу новије верзије позадинског механизма високих перформанси и SIP мост.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "Мобилни клијенти тренутно не подржавају позиве шифроване с-краја-на-крај.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Кликом на горње дугме се информације из формулара шаљу серверима фирме Struktur AG. Више информација можете да видите на {linkstart}spreed.eu{linkend}.",
    "Pending" : "На чекању",
    "Error" : "Грешка",
    "Blocked" : "Блокиран",
    "Active" : "Активан",
    "Expired" : "Истекао",
    "Never" : "Никад",
    "The trial could not be requested. Please try again later." : "Проба не може да се захтева. Молимо вас да покушате касније.",
    "The account could not be deleted. Please try again later." : "Налог не може да се обрише. Молимо вас да покушате касније.",
    "Hosted High-performance backend" : "Хостовани позадински механизам високих перформанси",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Наш партнер Struktur AG обезбеђује сервис којим може да се захтева хостовани сервер за сигнализацију. За ово је потребно само да испуните доњи формулар и ваш Nextcloud ће послати захтев. Једном кад се сервер постави за вас, подаци за пријаву ће се аутоматски попунити. Ово ће да препише постојећа подешавања сервера за сигнализацију.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Ако ваш позадински механизам има STUN и/или TURN функионалност, подешавања ће се ажурирати у складу са тим.",
    "URL of this Nextcloud instance" : "URL ове Nextcloud инстанце",
    "Full name of the user requesting the trial" : "Пуно име коринсика који захтева пробу",
    "Email of the user" : "И-мејл корисника",
    "Language" : "Језик",
    "Country" : "Држава",
    "Request signaling server trial" : "Захтев за пробу сервера за сигнализацију",
    "You can see the current status of your hosted signaling server in the following table." : "У следећој табели можете да видите статус свог хостованог сервера за сигнализацију.",
    "Status" : "Статус",
    "Created at" : "Направљено",
    "Expires at" : "Истиче дана",
    "Limits" : "Ограничења",
    "STUN included" : "STUN је укључен",
    "Yes" : "Да",
    "No" : "Не",
    "TURN included" : "TURN је укључен",
    "Delete the signaling server account" : "Обриши налог сервера за сигнализацију",
    "_%n user_::_%n users_" : ["%n корисник","%n корисника","%n корисника"],
    "Installed version: {version}" : "Инсталирана верзија: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Можете да инсталирате Matterbridge да бисте повезали Nextcloud Talk са неким другим сервисима, посетите њихову {linkstart1}GitHub страницу{linkend} за више детаља. Преузимање и инсталирање апликације може да потраје. У случају да истекне време, молимо вас да је ручно инсталирате из {linkstart2}Nextcloud продавнице апликација{linkend}.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "Matterbridge бинарни фајл нема исправне дозволе. Молимо вас да обезбедите да је власник Matterbridge бинарног фајла одговарајући корисник и да може да се изврши. Можете га пронаћи у „/…/nextcloud/apps/talk_matterbridge/bin/”.",
    "Matterbridge binary was not found or couldn't be executed." : "Није пронађен Matterbridge бинарни фајл, или не може да се изврши.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "У конфигурацији можете и ручно да поставите путању до Matterbridge бинарног фајла. Погледајте {linkstart}документацију Matterbridge интеграције{linkend} за више информација.",
    "Downloading …" : "Преузима се...",
    "Install Talk Matterbridge" : "Инсталирај Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "Дошло је до грешке приликом инсталирања Matterbridge апликације",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Дошло је до грешке током инсталације Talk Matterbridge. Молимо вас да је инсталирате ручно",
    "Failed to execute Matterbridge binary." : "Matterbridge бинарни фајл није могао да се изврши.",
    "Matterbridge integration" : "Matterbridge интеграција",
    "Enable Matterbridge integration" : "Укључи Matterbridge интеграцију",
    "Status: Checking connection" : "Статус: проверава се веза",
    "OK: Running version: {version}" : "OK: Верзија која се извршава: {version}",
    "Error: Server seems to be a Signaling server" : "Грешка: изгледа да је сервер Сервер за сигнализирање",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Грешка: системскко време Nextcloud сервера и сервера позадинског механизма снимања нису синхронизована. Молимо вас да обезбедите везу оба сервера са сервером тачног времена, или ручно ускладите време на њима.",
    "Recording backend URL" : "URL позадинског механизма за снимање",
    "Validate SSL certificate" : "Потвди SSL сертификат",
    "Delete this server" : "Обриши овај сервер",
    "Test this server" : "Тестирај овај сервер",
    "Disabled for all calls" : "Искључено за све позиве",
    "Enabled for all calls" : "Укључено за све позиве",
    "Configurable on conversation level by moderators" : "Модератори могу да подесе на нивоу разговора",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "PHP подешавања „upload_max_filesize” или „post_max_size” ће само да дозволе отпремање фајлова величине до {maxUpload}.",
    "Recording backend settings saved" : "Сачувана су подешавања позадинског механизма са снимање",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "Модератори ће моћи да укључе сагласност на нивоз разговора. Пре него што било који учесник приступи сваком позиву овог разговора, биће потребно да пристане да буде сниман.",
    "The consent to be recorded will be required for each participant before joining every call." : "Сагласност да буде сниман ће се тражити од сваког корисника пре него што приступи сваком позиву.",
    "The consent to be recorded is not required." : "Није потребна сагласност да се буде снимљен.",
    "Recording backend configuration is only possible with a High-performance backend." : "Конфигурација позадинског механизма за снимање је могућа само са позадинским механизмом високих перформанси.",
    "Add a new recording backend server" : "Додај нови сервер позадинског механизма за снимање",
    "Shared secret" : "Дељена тајна",
    "Recording consent" : "Сагласност за снимање",
    "Recording transcription" : "Транскрипт снимка",
    "Automatically transcribe call recordings with a transcription provider" : "Снимци разговора се аутоматски транскрибују помоћу пружаоца услуге транскрипције",
    "Automatically summarize call recordings with transcription and summary providers" : "Снимци разговора се аутоматски резимирају помоћу пружаоца услуге транскрипције и резимирања",
    "SIP configuration saved!" : "Сачувана је SIP конфигурација!",
    "SIP configuration is only possible with a High-performance backend." : "SIP конфигурација је могућа само са позадинским механизмом високих перформанси.",
    "Enable SIP Dial-out option" : "Укључи SIP одлазни позив опцију",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "Потребно је да се ажурира сигнализирајући сервер да би се могла користити SIP одлсзни позив функција.",
    "Do not show SIP Dial-out caller number" : "Не приказуј SIP одлазни број позиваоца",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "Анонимни број би примаоцу позива требало да се појави као „unknown” или „withheld number”",
    "Dial-out number" : "Одлазни број",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "E164 форматирани број који се користи као број позиваоца у крајњој нужди за одлазне позиве",
    "Dial-out prefix" : "Одлазни префикс",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "Префикс подешеног броја корисника за одлазне позиве (подразумевано је `+`)",
    "Restrict SIP configuration" : "Ограничи SIP конфигурисање",
    "Enable SIP configuration" : "Омогући SIP конфигурисање",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Само корисници следећих група могу да укључе SIP у разговорима које модеришу",
    "Phone number (Country)" : "Број телефона (Земља)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Ове информације се шаљу у е-порукама са позивницама и приказују се на бочној траци свим учесницима.",
    "Nextcloud base URL" : "Nextcloud базна URL адреса",
    "Talk Backend URL" : "URL адреса Talk позадинског механизма",
    "WebSocket URL" : "URL адреса WebSocket сервера",
    "Available features" : "Доступне фукнционалности",
    "Error: Websocket connection failed" : "Грешка: Websocket веза није успела",
    "Error code" : "Кôд грешке",
    "Error message" : "Порука о грешки",
    "Error: Websocket connection failed. Check browser console" : "Грешка: Websocket веза није успела. Погледајте конзолу интернет прегледача",
    "High-performance backend URL" : "URL позадинског механизма високих перформанси",
    "Missing High-performance backend warning hidden" : "Сакривено је упозорење о недостајућем позадинском механизму високих перформанси",
    "High-performance backend settings saved" : "Сачувана су подешавања позадинског механизма високих перформанси",
    "Nextcloud Talk setup not complete" : "Nextcloud Talk подешавање није довршено",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Молимо вас да имате на уму да ће се у позивима са више од 2 учесника без позадинског механизма високих перформанси искусити проблеми са везом и велико оптерећење уређаја учесника у разговору.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Инсталирајте позадински механизам високих перформанси да би позиви са више учесника функционисали беспрекорно.",
    "Nextcloud portal" : "Nextcloud портал",
    "Quick installation guide" : "Брзи водич за инсталацију",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "За позиве са више учесника је неопходан позадински механизам високих перформанси. Без њега, сви учесници појединачно морају да отпремају свој видео сваком осталом учеснику, што ће највероватније да проузрокује проблеме са повезивањем и велико оптерећење уређаја који учествују у позиву.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "Када се користи Nextcloud Talk са позадинским механизмом високих перформанси, снажно се препоручује да се подеси дистрибуирани кеш.",
    "Add High-performance backend server" : "Додај сервер позадинског механизма високих перформанси",
    "Warn about connectivity issues in calls with more than 2 participants" : "Упозоравај на проблеме са конекцијом у разговорима са више од 2 учесника",
    "STUN server URL" : "Адреса „STUN“ сервера",
    "The server address is invalid" : "Адреса сервера није исправна",
    "STUN settings saved" : "Сачувана су STUN подешавања",
    "STUN servers" : "„STUN“ сервери",
    "A STUN server is used to determine the public IP address of participants behind a router." : "„STUN“ сервер се користи да одреди јавну ИП адресу учесника који су иза рутера.",
    "Add a new STUN server" : "Додај нови STUN сервер",
    "{schema} scheme must be used with a domain" : "{schema} шема мора да се користи са доменом",
    "{option1} and {option2}" : "{option1} и {option2}",
    "{option} only" : "само {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "OK: TURN сервер је вратио успешне ICE кандидате",
    "Error: No working ICE candidates returned by the TURN server" : "OK: TURN сервер није вратио ICE кандидате који раде",
    "Testing whether the TURN server returns ICE candidates" : "Тестирање да ли TURN сервер враћа ICE кандидате",
    "TURN server schemes" : "Шеме TURN сервера",
    "TURN server URL" : "Адреса TURN сервера",
    "TURN server secret" : "Тајна TURN сервера",
    "TURN server protocols" : "TURN серверски протокол",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "TURN сервер се користи да прослеђује саобраћај од учесника који се налазе иза заштитног зида. Ако поједини учесници не могу да се повеђу са осталима, највероватније је потребан TURN сервер. За упутства о подешавању, погледајте {linkstart}ову документацију{linkend}.",
    "TURN settings saved" : "Сачувана су TURN подешавања",
    "TURN servers" : "TURN сервери",
    "Add a new TURN server" : "Додај нови TURN сервер",
    "Failed" : "Није успело",
    "OK" : "У реду",
    "Checking …" : "Проверавам…",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Неуспешно: WebAssembly је искључен или га овај прегледач не подржава. Да би се извршила провера, молимо вас да укључите WebAssembly или да користите прегледач који га подржава.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Неуспешно: веб сервер није исправно вратио „.wasm” и „.tflite” фајлове. Молимо вас да погледате одељак „System requirements” у Talk документацији.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK: веб сервер је исправно вратио „.wasm” и „.tflite” фајлове.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Изгледа да PHP и Apache конфигурација није компатибилна. Имајте на уму да PHP може да се користи само са MPM_PREFORK модулом и да PHP-FPM може да се користи само са MPM_EVENT модулом.",
    "Web server setup checks" : "Провере подешавања веб сервера",
    "Files required for virtual background can be loaded" : "Могу да се учитају фајлови неопходни за виртуелну позадину",
    "Federated user" : "Федерисани корисник",
    "Assign participants to rooms" : "Додели учеснике собама",
    "Configure breakout rooms" : "Конфигуриши сепарее",
    "Number of breakout rooms" : "Број сепареа",
    "You can create from 1 to 20 breakout rooms." : "Можете да креирате од 1 до 20 сепареа",
    "Assignment method" : "Метод доделе",
    "Automatically assign participants" : "Аутоматски додели учеснике",
    "Manually assign participants" : "Ручно додели учеснике",
    "Allow participants to choose" : "Дозволи да учесници изаберу",
    "Create rooms" : "Креирај собе",
    "Confirm" : "Потврди",
    "Create breakout rooms" : "Креирај сепарее",
    "Reset" : "Ресетуј",
    "Delete breakout rooms" : "Обриши сепарее",
    "Room {roomNumber}" : "Соба {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Текући сепаре и подешавања ће се изгубити",
    "Cancel" : "Откажи",
    "Unassigned participants" : "Недодељени учесници",
    "Back" : "Назад",
    "Assign" : "Додели",
    "Add participant \"{user}\"" : "Додај учесника „{user}”",
    "Now" : "Сада",
    "Invalid calendar selected" : "Изабран је неисправан календар",
    "Invalid start time selected" : "Изабрано је неисправно време почетка",
    "Invalid end time selected" : "Изабрано је неисправно време краја",
    "Unknown error occurred" : "Дошло је до непознате грешке",
    "Sending no invitations" : "Не шаље се ниједна позивница",
    "{participant0} will receive an invitation" : "{participant0} ће примити позивницу",
    "{participant0} and {participant1} will receive invitations" : "{participant0} и {participant1} ће примити позивницу",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} и још %n ће примити позивнице","{participant0}, {participant1} и још %n осталих ће примити позивнице","{participant0}, {participant1} и још %n осталих ће примити позивнице"],
    "Invite {user}" : "Позови {user}",
    "Invite all users and emails in this conversation" : "Позови све кориснике и и-мејл адресе у овај разговор",
    "Meeting created" : "Креиран је састанак",
    "Upcoming meetings" : "Предстојећи састанци",
    "No upcoming meetings" : "Нема предстојећих састанака",
    "Schedule a meeting" : "Закажи састанак",
    "Meeting title" : "Наслов састанка",
    "From" : "Од",
    "To" : "За",
    "Calendar" : "Календар",
    "Attendees" : "Присутни",
    "No other participants to send invitations to." : "Нема осталих учесника којима би могла да се пошаље позивница.",
    "Add attendees" : " Додај учеснике",
    "Save" : "Сачувај",
    "Search participants" : "Претражи учеснике",
    "No results" : "Нема резултата",
    "Done" : "Завршено",
    "Disable live transcription" : "Искључи транскрипцију уживо",
    "Exit full screen (F)" : "Напусти пун екран (F)",
    "Full screen (F)" : "Пун екран (F)",
    "Speaker view" : "Поглед говорника",
    "Grid view" : "Приказ мреже",
    "Error when trying to load the available live transcription languages" : "Грешка приликом покушаја учитавања доступних језика за транскрипцију уживо",
    "Failed to enable live transcription" : "Није успело укључивање транскрипције уживо",
    "Recording consent is required" : "Потребна је сагласност за снимање",
    "This conversation is read-only" : "Овај разговор је само-за-читање",
    "Conversation not found or not joined" : "Није пронађен разговор или му нисте приступили",
    "Lobby is still active and you're not a moderator" : "Предсобље је још увек активно и ви нисте модератор",
    "Connection failed" : "Није успело повезивање",
    "Reload" : "Поново учитај",
    "{nickName} raised their hand." : "{nickName} је подигао руку.",
    "A participant raised their hand." : "Учесник је подигао руку.",
    "Collapse stripe" : "Сажми црту",
    "Expand stripe" : "Развиј црту",
    "Previous page of videos" : "Претходна страница видеа",
    "Next page of videos" : "Наредна страница видеа",
    "Connecting …" : "Повезивање ..",
    "Calling …" : "Позивање",
    "Waiting for {user} to join the call" : "Чека се да {user} приступи позиву",
    "Waiting for others to join the call …" : "Чекам да се остали прикључе разговору…",
    "You can invite others in the participant tab of the sidebar" : "Можете позвати остале у језичку са учесницима у траци са стране",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Можете позвати остале у језичку са учесницима у траци са стране или поделити ову везу као позивницу!",
    "Share this link to invite others!" : "Поделите ову везу да позовете остале!",
    "Copy link" : "Копирај везу",
    "You are not allowed to enable audio" : "Није вам дозвољено да укључите звук",
    "No audio. Click to select device" : "Нема звука. Кликните да изаберете уређај",
    "Mute audio" : "Искључи звук",
    "Mute audio (M)" : "Утули звук (М)",
    "Unmute audio" : "Пусти звук",
    "Unmute audio (M)" : "Пусти звук (М)",
    "None" : "Нико",
    "Select a microphone" : "Изаберите микрофон",
    "Select a speaker" : "Изаберите звучник",
    "Check devices" : "Провери уређаје",
    "Access to camera was denied" : "Приступ камери је одбијен",
    "Error while accessing camera: It is likely in use by another program" : "Грешка приликом приступања камери: највероватније је користи неки други програм",
    "Error while accessing camera" : "Грешка приликом приступања камери",
    "You have been muted by a moderator" : "Модератор вас је утишао",
    "Hide presenter video" : "Сакриј видео презентера",
    "You are not allowed to enable video" : "Није вам дозвољено да укључите видео",
    "No video. Click to select device" : "Нема видеа. Кликните да изаберете уређај",
    "Disable video" : "Искључи видео",
    "Disable video (V)" : "Искључи видео (V)",
    "Enable video" : "Укључи видео",
    "Enable video (V)" : "Укључи видео (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Укључи видео - Ваша веза ће накратко бити прекинута док се видео укључује по први пут",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Укључи видео (V) - Ваша веза ће накратко бити прекинута док се видео укључује по први пут",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Укључи видео. Ваша веза ће накратко бити прекинута док се видео укључује по први пут",
    "Select a video device" : "Изаберите видео уређај",
    "Show presenter" : "Прикажи особу која излаже",
    "You" : "Ви",
    "Mute" : "Утули",
    "Muted" : "Утуљено",
    "Show screen" : "Прикажи екран",
    "Stop following" : "Прекини праћење",
    "Connection could not be established …" : "Није могла да се успостави веза...",
    "Connection was lost and could not be re-established …" : "Веза је изгубљена и није могла поново да се успостави...",
    "Connection could not be established. Trying again …" : "Није могла да се успостави веза. Покушава се поново...",
    "Connection lost. Trying to reconnect …" : "Веза је изгубљена. Покушава се поновно повезивање...",
    "Connection problems …" : "Проблеми са везом",
    "Collapse" : "Скупи",
    "Expand" : "Proširi",
    "You need to be logged in to upload files" : "Да бисте отпремали фајлове, морате бити пријављени",
    "Drop your files to upload" : "Отпустите фајлове за отпремање",
    "Conversation messages" : "Поруке у разговору",
    "Scroll to bottom" : "Скролуј на дно",
    "Post message" : "Објави поруку",
    "Federated conversation" : "Федерисани разговор",
    "Public conversation" : "Јавни разговор",
    "Favorite" : "Омиљени",
    "Banned users" : "Забрањени корисници",
    "Manage the list of banned users in this conversation." : "Управљање листом забрањених корисника у овом разговору.",
    "Manage bans" : "Управљај забранама",
    "No banned users" : "Нема забрањених корисника",
    "Banned by:" : "Забранио:",
    "Date:" : "Датум:",
    "Note:" : "Белешка:",
    "Hide details" : "Сакриј детаље",
    "Show details" : "Прикажи детаље",
    "Unban" : "Уклони забрану",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "Наслов и опис можете да промените у {linkstart}Календару ↗{linkend}.",
    "Error while updating conversation name" : "Грешка приликом ажурирања назива разговора",
    "Error while updating conversation description" : "Грешка приликом ажурирања описа разговора",
    "Enter a name for this conversation" : "Унесите назив овог разговора",
    "Edit conversation name" : "Уреди назив разговора",
    "Edit conversation description" : "Уреди опис разговора",
    "Enter a description for this conversation" : "Унесите опис овог разговора",
    "Picture" : "Слика",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "У овом разговору могу да се укључе следећи ботови. Обратите се администрацији ако желите да добијете још ботова инсталираних на овом серверу.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "На овом серверу није инсталиран ниједан бот. Обратите се администрацији ако желите да инсталирате ботове на овај сервер.",
    "Disable" : "Искључи",
    "Enable" : "Укључи",
    "Breakout rooms" : "Сепареи",
    "Manage breakout rooms" : "Управљај сепареима",
    "Set up breakout rooms for this conversation" : "Подесите сепарее за овај разговор",
    "Please select a valid PNG or JPG file" : "Молимо вас да изаберете исправан PNG или JPG фајл",
    "Choose your conversation picture" : "Изаберите слику за свој разговор",
    "Choose" : "Изаберите",
    "Error setting conversation picture" : "Грешка приликом постављања слике разговора",
    "Could not set the conversation picture: {error}" : "Није могла да се постави слика разговора: {error}",
    "Error cropping conversation picture" : "Грешка приликом опсецања слике разговора",
    "Error removing conversation picture" : "Грешка приликом уклањања слике разговора",
    "Set emoji as conversation picture" : "Постави емођи као слику разговора",
    "Set background color for conversation picture" : "Постави боју позадине слике разговора",
    "Upload conversation picture" : "Отпреми слику разговора",
    "Choose conversation picture from files" : "Изабери слику разговора међу фајловима",
    "Remove conversation picture" : "Уклони слику разговора",
    "The file must be a PNG or JPG" : "Фајл мора да буде PNG или JPG",
    "Set picture" : "Постави слику",
    "Default permissions modified for {conversationName}" : "Подразумеване дозволе измењене за {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Нису могле да се измене подразумеване дозволе за {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Уређивање подразумеваних дозвола за учеснике овог разговора. Ова подешавања не утичу на модераторе.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Сваки пут када се у овом одељку измене дозволе, губе се произвољне дозволе које су раније додељене појединим учесницима.",
    "All permissions" : "Све дозволе",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Учесници имају дозволу да започну позив, приступе позиву, укључе звук и видео и деле екран.",
    "Restricted" : "Ограничена",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Учесници могу да приступе позивима, али не могу да укључе ни звук ни видео, нити могу да деле екран све док им модератор то не дозволи.",
    "Advanced permissions" : "Напредне дозволе",
    "Edit permissions" : "Уреди дозволе",
    "Conversation settings" : "Подешавања разговора",
    "Basic Info" : "Основне информације",
    "Personal" : "Лично",
    "Moderation" : "Модерација",
    "Setup overview" : "Подеси преглед",
    "Live transcription" : "Транскрипција уживо",
    "Enable live transcription" : "Укључи транскрипцију уживо",
    "Breakout Rooms" : "Сепареи",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Ботови",
    "Danger zone" : "Зона опасности",
    "Archive conversation" : "Архивирај разговор",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Архивирани разговори се подразумевано не виде на листи разговора. Међутим, ипак ће се појављивати када претражујете по имену разговора или приступите листи архивираних разговора.",
    "Do you really want to leave \"{displayName}\"?" : "Да ли заиста желите да напустите „{displayName}”?",
    "You can archive this conversation instead." : "Уместо тога, овај разговор можете да архивирате.",
    "Leave conversation" : "Напусти разговор",
    "You need to promote a new moderator before you can leave the conversation" : "Морате да промовишете новог модератора пре него што напустите разговор",
    "Delete conversation" : "Обриши разовор",
    "Do you really want to delete \"{displayName}\"?" : "Да ли заиста желите да обришете „{displayName}”?",
    "Error while deleting conversation" : "Грешка приликом брисања разговора",
    "Delete all chat messages" : "Обриши све чет поруке",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Да ли заиста желите да обришете све поруке у „{displayName}”?",
    "Error while clearing chat history" : "Грешка приликом брисања чет историје",
    "Be careful, these actions cannot be undone." : "Будите опрезни, ове акције не могу да се пониште",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Једном када се разговор напусти, за поновно приступање затвореном разговору је потребна позивница. Отвореном разговору може да се поново приступи у било које време.",
    "Permanently delete this conversation." : "Трајно брисање оваг разговора.",
    "Delete chat messages" : "Обриши чет поруке",
    "Permanently delete all the messages in this conversation." : "Трајно брисање свих порука у овом разговору.",
    "Custom expiration time" : "Произвољно време трајања",
    "Message expiration disabled" : "Искључен је рок трајања поруке",
    "Message expiration set: {duration}" : "Постављен је рок трајања поруке: {duration}",
    "Error when trying to set message expiration" : "Грешка приликом покушаја да се постави рок трајања поруке",
    "Message expiration" : "Рок трајања поруке",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Чет поруке могу да истекну након одређеног времена. Напомена: фајлови који су подељени у чету се неће обрисати за власника, али више неће бити дељени у разговору.",
    "Set message expiration" : "Постави рок важења поруке",
    "Current message expiration" : "Текући рок важења поруке",
    "Password copied to clipboard" : "Лозинка је копирана у клипборд",
    "Password could not be copied" : "Лозинка није могла да се копира",
    "Guest access" : "Приступ госта",
    "Breakout rooms are not allowed in public conversations." : "У јавним разговорима нису дозвољени сепареи.",
    "Allow guests to join this conversation via link" : "Дозволи да гости приступе разговору путем линка",
    "Password protection" : "Заштита лозинком",
    "This conversation is password-protected. Guests need password to join" : "Овај разговор је заштићен лозинком. Гости морају да наведу лозинку ако желе да се придруже",
    "Password protection is needed for public conversations" : "За јавне разговоре је обавезна заштита лозинком",
    "Set a password" : "Постави лозинку",
    "Change password" : "Измени лозинку",
    "Enter new password" : "Унесите нову лозинку",
    "Save password" : "Сачувај лозинку",
    "Copy password" : "Копирај лозинку",
    "Guests are allowed to join this conversation via link" : "Гости могу да приступе овом разговору путем линка",
    "Guests are not allowed to join this conversation" : "Гости не могу да приступе овом разговору",
    "Resend invitations" : "Поново пошаљи позивнице",
    "This conversation is open to both registered users and users created with the Guests app" : "Овај разговор је отворен и за регистроване и за кориснике креиране апликацијом Гости",
    "This conversation is open to registered users" : "Овај разговор је отворен за регистроване кориснике",
    "This conversation is limited to the current participants" : "Овај разговор је ограничен на тренутне учеснике",
    "You opened the conversation to both registered users and users created with the Guests app" : "Отворили сте разговор свим регистрованим корисницима и корисницима креиранима апликацијом Гости",
    "Error occurred when opening or limiting the conversation" : "Дошло је до грешке током отварања или ограничавања разговора",
    "Open conversation to registered users, showing it in search results" : "Отвори разговор за регистроване кориснике и приказуј га у резултатима претраге",
    "Also open to users created with the Guests app" : "Такође је отворен корисницима креираним апликацијом Гости",
    "Open conversation" : "Отвори разговор",
    "Set language spoken in calls" : "Поставите језике који се говоре у позивима",
    "Languages could not be loaded" : "Нису могли да се учитају језици",
    "Loading languages …" : "Језици се учитавају",
    "Invalid language" : "Неисправни језик",
    "Default language (English)" : "Подразумевани језик (енглески)",
    "Default live transcription language set" : "Постављен је подразумевани језик за транскрипцију уживо",
    "Live transcription language set: {languageName}" : "Постављени језик за транскрипцију уживо: {languageName}",
    "Error when trying to set live transcription language" : "Грешка приликом покушаја постављања језика за транскрипцију уживо",
    "Start time: {date}" : "Време почетка: {date}",
    "Start time has been updated" : "Ажурирано је време почетка",
    "Error occurred while updating start time" : "Дошло је до грешке приликом ажурирања времена почетка",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Укључивање предсобља ће да из текућег позива уклони све учеснике који нису модератори.",
    "Enable lobby, restricting the conversation to moderators" : "Укључи предсобље и ограничи разговор само на модераторе",
    "Meeting start time" : "Време почетка састанка",
    "Start time (optional)" : "Време почетка (опционо)",
    "Import email participants" : "Увези и-мејл учеснике",
    "You can import a list of email participants from a CSV file." : "Листу и-мејл учесника можете да увезете из CSV фајла.",
    "Poll drafts" : "Нацрти гласања",
    "Browse poll drafts" : "Прегледај нацрте гласања",
    "Error occurred when locking the conversation" : "Дошло је до грешке приликом закључавања разговора",
    "Error occurred when unlocking the conversation" : "Дошло је до грешке приликом откључавања разговора",
    "Lock conversation" : "Закључај разговор",
    "This will also terminate the ongoing call." : "Ово ће такође да прекине текући позив.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Закључај разговор и спречи све да објављују поруке или започињу позиве",
    "Edit" : "Измени",
    "More information" : "Још информација",
    "Delete" : "Избриши",
    "Add new bridged channel to current conversation" : "Додај нови премошћени канал у текући разговор",
    "unknown state" : "непознато стање",
    "running" : "извршава се",
    "not running, check Matterbridge log" : "не извршава се, погледајте Matterbridge дневник",
    "not running" : "не извршава се",
    "Bridge saved" : "Мост је сачуван",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Са Matterbridge можете да премостите канале са разних система за тренутну размену порука.",
    "More info on Matterbridge" : "Више информација о Matterbridge",
    "Messaging systems" : "Системи за размену порука",
    "Enable bridge" : "Укључи мост",
    "Show Matterbridge log" : "Прикажи Matterbridge дневник",
    "Log content" : "Садржај дневника",
    "Only moderators are allowed to mention @all" : "Само модератори смеју да помену @all",
    "All participants are allowed to mention @all" : "Сви учесници смеју да помену @all",
    "Participants are now allowed to mention @all." : "Учесници не смеју да помену @all.",
    "Mentioning @all has been limited to moderators." : "Помињање @all је ограничено на модераторе.",
    "Allow participants to mention @all" : "Дозволи да учесници помену @all",
    "Mention permissions" : "Дозволе за помињање",
    "Notifications" : "Обавештења",
    "Notify about calls in this conversation" : "Обавести о позивима у овом разговору",
    "Important conversation" : "Битан разговор",
    "\"Do not disturb\" user status is ignored for important conversations" : "Кориснички статус „Не узнемиравај” се игнорише за важне разговоре",
    "Sensitive conversation" : "Осетљиви разговор",
    "Message preview will be disabled in conversation list and notifications" : "Преглед поруке ће се сакрити у листи разговора и у обавештењима",
    "Recording consent is required for calls in this conversation" : "Сагласност за снимање се захтева за позиве у овом разговору",
    "Recording consent is not required for calls in this conversation" : "Сагласност за снимање није потребна за позиве у овом разговору",
    "Recording consent requirement was updated" : "Ажурирано је подешавање захтева за сагласност снимања",
    "Error occurred while updating recording consent" : "Дошло је до грешке приликом ажурирања сагласности за снмање",
    "Recording Consent" : "Сагласност за снимање",
    "Recording consent cannot be changed once a call or breakout session has started." : "Када се покрене позив или сесија сепареа, пристанак на снимање не може да се измени.",
    "Require recording consent before joining call in this conversation" : "Захтевај сагласност за снимање пре приступања позиву у овом разговору",
    "Recording consent is required for all calls" : "Сагласност за снимање се захтева за све позиве",
    "SIP dial-in is now possible without PIN requirement" : "SIP приступ је сада могућ без уношења PIN",
    "SIP dial-in is now enabled" : "Сада је укључен SIP приступ",
    "SIP dial-in is now disabled" : "Сада је искључен SIP приступ",
    "Error occurred when enabling SIP dial-in" : "Дошло је до грешке приликом укључивања SIP приступа",
    "Error occurred when disabling SIP dial-in" : "Дошло је до грешке приликом искључивања SIP приступа",
    "Phone and SIP dial-in" : "Телефонски и SIP приступ",
    "Enable phone and SIP dial-in" : "Уљкучи телефонски и SIP приступ",
    "Allow to dial-in without a PIN" : "Дозволи приступ без PIN",
    "Ongoing" : "Траје",
    "{dayPrefix} {dateTime}" : "{dayPrefix} од {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n особа је прихватила","%n особа су прихватиле","%n особа је прихватило"],
    "_%n person declined_::_%n people declined_" : ["%n особа је одбила","%n особа су одбиле","%n особа је одбило"],
    "_and %n other attachment_::_and %n other attachments_" : ["и још %n прилог","и још %n прилога","и још %n прилога"],
    "With {displayName}" : "Са {displayName}",
    "In {conversation}" : "У {conversation}",
    "View attachment" : "Прикажи прилог",
    "Join" : "Придружи се",
    "View conversation" : "Прикажи разговор",
    "View event on Calendar" : "Прикажи догађај у Календару",
    "Error while creating the conversation" : "Грешка приликом креирања разговора",
    "Hello, {displayName}" : "Здраво, {displayName}",
    "Start meeting now" : "Започни састанак одмах",
    "Give your meeting a title" : "Дајте наслов свом састанку",
    "Create and copy link" : "Креирај и копирај линк",
    "Create a new conversation" : "Креирај нови разговор",
    "Join open conversations" : "Придружи се отвореном разговору",
    "Call a phone number" : "Позови телефонски број",
    "Scroll backward" : "Скролуј уназад",
    "Scroll forward" : "Скролуј унапред",
    "Schedule meetings" : "Закажи састанке",
    "You don't have any upcoming meetings" : "Немате ниједан предстојећи састанак",
    "Open calendar" : "Отвори календар",
    "Unread mentions" : "Непрочитана помињања",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "Овде ће се појавити поруке у којима сте поменути. Људе можете да поменете тако што откуцате @ испред њиховог имена",
    "Upcoming reminders" : "Предстојећи подсетници",
    "Message reminders" : "Подсетници о порукама",
    "Set a reminder on a message to be notified" : "Поставите подсетник на поруку да би сте били обавештени",
    "Start a group conversation" : "Започни групни разговор",
    "Create conversation" : "Креирај разговор",
    "Enter your name" : "Унесите Ваше име",
    "Submit name and join" : "Поднеси име и приступи",
    "Do you already have an account?" : "Да ли већ имате налог?",
    "Log in" : "Пријава",
    "Error while verifying uploaded file" : "Грешка током провере отпремљеног фајла",
    "Uploaded file is verified" : "Отпремљени фајл је проверен",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "Формат садржаја су вредности раздвојене запетом (CSV):<br/>- Линија заглавља је потребна и мора да се подудара са <samp>\"name\",\"email\"</samp> или само <samp>\"email\"</samp><br/>- Једна ставка по линији (нпр. <samp>\"Петар Петровић\",\"pera@primer.tld\"</samp>)",
    "Participants added successfully" : "Учесници су успешно додати",
    "Error while adding participants" : "Грешка приликом додавања учесника",
    "Import a file" : "Увези фајл",
    "Browse" : "Прегледај",
    "Verifying uploaded file …" : "Отпремљени фајл се потврђује",
    "This might take a moment" : "Ово би могло мало да потраје",
    "Send invitations" : "Пошаљи позивнице",
    "_%n invalid email_::_%n invalid emails_" : ["%n неисправан и-мејл","%n неисправна и-мејла","%n неисправних и-мејлова"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n и-мејл је већ увезен или је дупликат","%n и-мејла су већ увезени или су дупликати","%n и-мејлова је већ увезено или су дупликати"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["%n позивница може да се пошаље","%n позивнице могу да се пошаљу","%n позивница може да се пошаље"],
    "An error occurred while calling a phone number" : "Дошло је до грешке током позивања телефонског броја",
    "Phone number could not be called: {error}" : "Телефонски број не може да се позове: {error}",
    "Phone number could not be called" : "Телефонски број не може да се позове",
    "Search participants or phone numbers" : "Претражи учеснике или телефонске бројеве",
    "Creating the conversation …" : "Разговор се креира",
    "Mark as read" : "Означи као прочитано",
    "Mark as unread" : "Означи као непрочитано",
    "Remove from favorites" : "Уклони из омиљених",
    "Add to favorites" : "Додаје у омиљене",
    "Unarchive conversation" : "Деархивирај разговор",
    "Ignore \"Do not disturb\"" : "Игнориши „Не узнемиравај”",
    "You need to promote a new moderator before you can leave the conversation." : "Морате унапредити новог модератора пре него што напустите разговор.",
    "New tag" : "Нова ознака",
    "Tag name" : "Назив ознаке",
    "Conversation actions" : "Акције разговора",
    "Tags" : "Ознаке",
    "Notify about calls" : "Обавести о позивима",
    "Hide message text" : "Сакриј текст поруке",
    "Rename tag" : "Промени назив ознаке",
    "Delete tag" : "Обриши ознаку",
    "Move up" : "Помери нагоре",
    "Move down" : "Помери надоле",
    "Pending invitations" : "Позивнице на чекању",
    "From {user} at {remoteServer}" : "Од {user} на {remoteServer}",
    "Decline invitation" : "Одбиј позивницу",
    "Accept invitation" : "Прихвати позивницу",
    "No pending invitations" : "Нема позивница на чекању",
    "Home" : "Почетна",
    "Unread" : "Непрочитано",
    "Mentions" : "Помињања",
    "Meetings" : "Састанци",
    "Alphabetically" : "Абецедно",
    "No followed threads" : "Нема низова које пратите",
    "No matches found" : "Нема подударања",
    "No conversations found" : "Није пронађен ниједан разговор",
    "You have no archived conversations." : "Немате ниједан архивирани разговор.",
    "Subscribe to an existing thread or start your own." : "Претплатите се не постојећи низ или започните свој.",
    "You have no unread mentions." : "Немате помињања која нисте прочитали.",
    "You have no unread messages." : "Немате порука која нисте прочитали.",
    "An error occurred while performing the search" : "Грешка приликом претраге",
    "Conversation list" : "Листа разговора",
    "Filter conversations by" : "Филтрирај разговоре по",
    "Unread messages" : "Непрочитане поруке",
    "Meeting conversations" : "Разговори у састанку",
    "Clear filters" : "Уклони филтере",
    "New personal note" : "Нова лична белешка",
    "Back to conversations" : "Назад на разговоре",
    "Threads" : "Нити",
    "Archived conversations" : "Архивирани разговори",
    "Clear filter" : "Очисти филтер",
    "Show more threads" : "Прикажи још нити",
    "App settings" : "Подешавања апликације",
    "Users" : "Корисници",
    "Groups" : "Групе",
    "Teams" : "Тимови",
    "Federated users" : "Федерисани корисници",
    "New private conversation" : "Нови приватни разговор",
    "Other sources" : "Остали извори",
    "Open conversations" : "Отвори разговор",
    "No search results" : "Нема резултата претраге",
    "Users, groups and teams" : "Корисници, групе и тимови",
    "Users and groups" : "Корисници и групе",
    "Users and teams" : "Корисници и тимови",
    "Groups and teams" : "Групе и тимови",
    "New group conversation" : "Нови групни разговор",
    "The meeting will start soon" : "Састанак ће ускоро да почне",
    "This meeting is scheduled for {startTime}" : "Овај састанак је заказан за {startTime}",
    "You are currently waiting in the lobby" : "Тренутно чекате у лобију",
    "Advanced" : "Напредно",
    "Select microphone" : "Изаберите микрофон",
    "No microphone available" : "Нема доступног микрофона",
    "Select speaker" : "Изаберите говорника",
    "No speaker available" : "Није доступан ниједан говорник",
    "Select camera" : "Изаберите камеру",
    "No camera available" : "Нема доступне камере",
    "Select a device" : "Изаберите уређај",
    "Playing …" : "Пушта се",
    "Test speakers" : "Тест звучника",
    "Test" : "Тест",
    "Devices" : "Уређаји",
    "Backgrounds" : "Позадине",
    "No audio" : "Нема звука",
    "No camera" : "Без камере",
    "Display video as you will see it (mirrored)" : "Видео се приказује онако како га ви видите (у огледалу)",
    "Display video as others will see it" : "Видео се приказује онако како виде остали",
    "Calls are not supported in your browser" : "Ваш прегледач не подржава позиве",
    "Access to microphone is only possible with HTTPS" : "Приступ микрофону је могућ само кроз HTTPS протокол",
    "Access to microphone was denied" : "Приступ микрофону је одбијен",
    "Error while accessing microphone" : "Грешка приликом приступања микрофону",
    "Access to camera is only possible with HTTPS" : "Приступ камери је могућ само кроз HTTPS протокол",
    "The call is being recorded." : "Позив се снима.",
    "The call might be recorded." : "Овај позив би могао да се снима.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "Може се снимати ваш глас, видео са камере и садржај екрана који делите. Пре него што приступите позиву, морате дати своју сагласност.",
    "Give consent to the recording of this call" : "Дајте сагласност за снимање овог позива",
    "Show more info" : "Прикажи више информација",
    "Audio is not available" : "Није доступан аудио",
    "Video is not available" : "Није доступан видео",
    "Start recording immediately with the call" : "Одмах започни снимање заједно са позивом",
    "Notify all participants about this call" : "Обавести све учеснике о овом позиву",
    "Apply settings" : "Примени подешавања",
    "Select virtual office background" : "Изаберите позадину виртуелне канцеларије",
    "Select virtual home background" : "Изаберите позадину виртуелног дома",
    "Select virtual abstract background" : "Изаберите апстрактну виртуелну позадину",
    "Select virtual beach background" : "Изаберите позадину виртуелне плаже",
    "Select virtual park background" : "Изаберите позадину виртуелног парка",
    "Select virtual theater background" : "Изаберите позадину виртуелног позоришта",
    "Select virtual library background" : "Изаберите позадину виртуелне библиотеке",
    "Select virtual space station background" : "Изаберите позадину виртуелне свемирске станице",
    "Error while uploading the file" : "Грешка приликом отпремања фајла",
    "Select a file" : "Изаберите фајл",
    "Invalid path selected" : "Одабрана неисправна путања",
    "Select virtual background from file {fileName}" : "Изаберите виртуелну позадину из фајла {fileName}",
    "Blur" : "Замућење",
    "Upload" : "Отпреми",
    "Files" : "Фајлови",
    "(editing)" : "(уређивање)",
    "(edited)" : "(уређено)",
    "The message has expired or has been deleted" : "Рок важења поруке је истекао или је обрисана",
    "Cancel quote" : "Откажи цитат",
    "24 hours" : "24 сата",
    "7 days" : "7 дана",
    "Clear reminder – {timeLocale}" : "Обриши подсетник – {timeLocale}",
    "Edited by {actor}" : "Уредио је {actor}",
    "Message text copied to clipboard" : "Текст поруке је копиран у клипборд",
    "Message text could not be copied" : "Текст поруке није могао да се копира",
    "Message forwarded to \"Note to self\"" : "Порука је прослеђена у „Белешка самом себи”",
    "Error while forwarding message to \"Note to self\"" : "Грешка приликом прослеђивања поруке у „Белешка самом себи”",
    "A reminder was successfully removed" : "Подсетник је успешно уклоњен",
    "Error occurred when removing a reminder" : "Дошло је до грешке приликом уклањања подсетника",
    "A reminder was successfully set at {datetime}" : "Подсетник је успешно постављен на {datetime}",
    "Error occurred when creating a reminder" : "Дошло је до грешке током креирања подсетника",
    "Add a reaction to this message" : "Додај реакцију на ову поруку",
    "Reply" : "Одговори",
    "More actions" : "Још акција",
    "Set reminder" : "Постави подсетник",
    "Reply privately" : "Одговори приватно",
    "Edit message" : "Уреди поруку",
    "Copy message" : "Копирај поруку",
    "Copy message link" : "Копирај линк поруке",
    "Go to file" : "Иди на фајл",
    "Download file" : "Преузми фајл",
    "Go to thread" : "Иди на нит",
    "Edit thread details" : "Уреди детаље о низу",
    "Forward message" : "Проследи поруку",
    "Translate" : "Превођење",
    "Set custom reminder" : "Постави произвољни подсетник",
    "Close reactions menu" : "Затвори мени реакција",
    "React with {emoji}" : "Реагуј са {emoji}",
    "React with another emoji" : "Реагуј са другим емођијем",
    "Choose a conversation to forward the selected message." : "Изаберите разговор на који треба да се проследи изабрана порука.",
    "Error while forwarding message" : "Грешка приликом прослеђивања поруке",
    "The message has been forwarded to {selectedConversationName}" : "Порука је прослеђена у {selectedConversationName}",
    "Dismiss" : "Уклони",
    "Go to conversation" : "Иди на разговор",
    "Detect language" : "Откриј језик",
    "The message could not be translated" : "Није могла да се преведе порука",
    "Translation copied to clipboard" : "Превод је копиран у клипборд",
    "Translation could not be copied" : "Превод није могао да се је копира",
    "Translate message" : "Преведи поруку",
    "Source language to translate from" : "Изворни језик са ког се преводи",
    "Translate from" : "Преведи са",
    "Target language to translate into" : "Циљни језик на који се преводи",
    "Translate to" : "Преведи на",
    "Translating" : "Преводи се",
    "Copy translated text" : "Копирај преведени текст",
    "Send now" : "Пошаљи одмах",
    "Message read by everyone who shares their reading status" : "Поруку су прочитали сви који деле свој статус читања",
    "Message sent" : "Порука послата",
    "Sent without notification" : "Послато без обавештења",
    "Deleting message" : "Брисање поруке",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "Порука је успешно обрисана, али је бот или Matterbridge тако подешен да је порука већ прослеђена осталим сервисима",
    "Message deleted successfully" : "Порука је успешно обрисана",
    "Message could not be deleted because it is too old" : "Порука није могла да се обрише јер је сувише стара",
    "Only normal chat messages can be deleted" : "Могу да се обришу само обичне чет поруке",
    "An error occurred while deleting the message" : "Дошло је до грешке приликом брисања поруке",
    "Your browser does not support playing audio files" : "Ваш прегледач не подржава пуштање звучних фајлова",
    "Contact" : "Контакт",
    "{stack} in {board}" : "{stack} у {board}",
    "Deck Card" : "Шпил картица",
    "Remove {fileName}" : "Уклони {fileName}",
    "Open this location in OpenStreetMap" : "Отвори ову локацију у OpenStreetMap",
    "_%n reply_::_%n replies_" : ["%n одговор","%n одговора","%n одговора"],
    "Sending message" : "Слање поруке",
    "Failed to send the message. Click to try again" : "Није успело слање поруке. Кликните да се покуша поново",
    "Not enough free space to upload file" : "Нема довољно слободног простора за отпремање фајла",
    "You cannot send messages to this conversation at the moment" : "Тренутно не можете да шаљете поруке у овај разговор",
    "Could not update the message" : "Није могла да се ажурира порука",
    "You voted" : "Гласали сте",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Нацрт гласања • %n опција","Нацрт гласања • %n опција","Нацрт гласања • %n опција"],
    "_%n vote_::_%n votes_" : ["%n глас","%n гласа","%n гласова"],
    "Edit poll draft" : "Уреди нацрт гласања",
    "Delete poll draft" : "Обриши нацрт гласања",
    "Open poll" : "Отворено гласање",
    "See results" : "Поглдајте резултате",
    "Reactions" : "Реакције",
    "No permission to post reactions in this conversation" : "Нема дозвола за објављивање реакција у овом разговору",
    "and {participant}" : "и {participant}",
    "_and %n other participant_::_and %n other participants_" : ["и још %n други учесник","и још %n друга учесника","и још %n других учесника"],
    "Show all reactions" : "Прикажи сва реаговања",
    "Add more reactions" : "Додај још реакција",
    "Show or collapse system messages" : "Прикажи или сажми системске поруке",
    "No messages" : "Нема порука",
    "All messages have expired or have been deleted." : "Свим порукама је истекао рок важења или су обрисане.",
    "Unpin" : "Откачи",
    "Cancel search" : "Откажи претрагу",
    "Add a phone number" : "Додаје телефонски број",
    "Error: A password is required to create the conversation." : "Грешка: потребна је лозинка да би се креирао разговор.",
    "All set, the conversation \"{conversationName}\" was created." : "Све је завршено, креиран је разговор „{conversationName}”.",
    "Create a new group conversation" : "Креирај нови групни разговор",
    "Add participants" : "Додај учеснике",
    "Maximum length exceeded ({maxlength} characters)" : "Прекорачена је максимална дужина ({maxlength} карактера)",
    "Conversation visibility" : "Видљивост разговора",
    "Allow guests to join via link" : "Дозволи да гости приступе путем линка",
    "Enter password" : "Унесите лозинку",
    "This conversation has been locked" : "Разговор је закључан",
    "No permission to post messages in this conversation" : "Нема дозвола за објављивање порука у овај разговор",
    "Joining conversation …" : "Приступа се разговору...",
    "Write a message without notification" : "Напиши поруку без обавештења",
    "Create a thread silently" : "Креирај низ у тишини",
    "Create a thread" : "Креирај нит",
    "Send message silently" : "Пошаљи поруку у тишини",
    "Send message" : "Пошаљи поруку",
    "Send without notification" : "Пошаљи без обавештења",
    "The participant will not be notified about new messages" : "Учесник неће бити обавештен о новим порукама",
    "Participants will not be notified about new messages" : "Учесници неће бити обавештени о новим порукама",
    "Thread title is required" : "Потребан је наслов низа",
    "Message text is required" : "Потребан је текст поруке",
    "The message could not be edited" : "Порука није могла да се уреди",
    "File to share" : "Фајл за дељење",
    "File upload is not available in this conversation" : "У овај разговор не може да се отпреми фајл",
    "Add emoji" : "Додај емођи",
    "Adding a mention will only notify users who did not read the message." : "Додавање помињања ће обавестити само кориснике који још увек нису прочитали поруку.",
    "Thread title" : "Наслов низа",
    "Send later" : "Пошаљи касније",
    "Cancel editing" : "Откажи уређивање",
    "{user} is out of office and might not respond." : "{user} је ван канцеларије у можда неће одговорити.",
    "Absence period: {startDate} - {endDate}" : "Период одсутности: {startDate} – {endDate}",
    "Replacement:" : "Замена:",
    "Share from {nextcloud}" : "Дељење од {nextcloud}",
    "Share from Files" : "Подели из Фајлова",
    "Share files to the conversation" : "Дели фајлове у разговор",
    "Upload from device" : "Отпреми са уређаја",
    "Create new poll" : "Направи ново гласање",
    "Smart picker" : "Паметни бирач",
    "Record voice message" : "Сними гласовну поруку",
    "End recording and send" : "Заврши снимање и пошаљи",
    "Dismiss recording" : "Одбаци снимак",
    "Access to the microphone was denied" : "Приступ микрофону је одбијен",
    "Microphone either not available or disabled in settings" : "Микрофон или није доступан, или је искључен у подешавањима",
    "Error while recording audio" : "Грешка приликом снимања звука",
    "Generating summary of unread messages …" : "Генерише се резиме непрочитаних порука",
    "Summary is AI generated and might contain mistakes" : "Резиме је генерисала AI и можда садржи грешке",
    "Error occurred during a summary generation" : "Дошло је до грешке током генерисања резимеа",
    "New file" : "Нови фајл",
    "Blank" : "Празно",
    "Error while creating file" : "Грешка приликом креирања фајла",
    "Create and share a new file" : "Креирај и подели нови фајл",
    "Name of the new file" : "Име новог фајла",
    "Create file" : "Креирај фајл",
    "Someone is typing …" : "Неко куца...",
    "{user1} is typing …" : "{user1} куца…",
    "{user1} and {user2} are typing …" : "{user1} и {user2} куцају…",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} и {user3} куцају…",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} и још %n корисник куцају…","{user1}, {user2}, {user3} и још %n корисника куцају…","{user1}, {user2}, {user3} и још %n корисника куцају…"],
    "Add more files" : "Додај још фајлова",
    "Send" : "Пошаљи",
    "In this conversation <strong>{user}</strong> can:" : "Корисник <strong>{user}</strong> у овом разговору може да:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Уреди подразумеване дозволе за учеснике разговора <strong>{conversationName}</strong>",
    "Start a call" : "Започни позив",
    "Skip the lobby" : "Прескочи предсобље",
    "Can post messages and reactions" : "Могу да се објаве поруке и реакције",
    "Enable the microphone" : "Укључи микрофон",
    "Enable the camera" : "Укључи камеру",
    "Share the screen" : "Дели екран",
    "Update permissions" : "Ажурирај дозволе",
    "Updating permissions" : "Ажурирање дозвола",
    "No poll drafts" : "Нема ниједног нацрта гласања",
    "There is no poll drafts yet saved for this conversation" : "За овај разговор још увек није сачуван ниједан нацрт гласања",
    "Create poll in {name}" : "Креирај гласање у {name}",
    "Create poll" : "Направи гласање",
    "Error while importing poll" : "Грешка током увоза гласања",
    "Question" : "Питање",
    "Ask a question" : "Постави питање",
    "Import draft from file" : "Увези нацрт из фајла",
    "Answers" : "Одговори",
    "Answer {option}" : "Одговор {option}",
    "Delete poll option" : "Обриши опцију гласања",
    "Add answer" : "Додај одговор",
    "Settings" : "Поставке",
    "Anonymous poll" : "Анонимно гласање",
    "Multiple answers" : "Вишеструки одговори",
    "Save as draft" : "Сачувај као нацрт",
    "Export draft to file" : "Извези нацрт из фајла",
    "You voted for this option" : "Гласали сте за ову опцију",
    "End poll" : "Заврши гласање",
    "Change your vote" : "Измените свој глас",
    "Results" : "Резултати",
    "Voted participants" : "Учесници који су гласали",
    "Send a message to \"{roomName}\"" : "Пошаљи поруку у „{roomName}”",
    "Hide list of participants" : "Сакриј листу учесника",
    "Show list of participants" : "Прикажи листу учесника",
    "Assistance requested in {roomName}" : "Затражена је помоћ у соби {roomName}",
    "The message was sent to \"{roomName}\"" : "Порука је послата у „{roomName}”",
    "Dismiss request for assistance" : "Одбаци захтев за помоћ",
    "Send message to room" : "Пошаљи поруку у собу",
    "Back to main room" : "Назад на главну собу",
    "Back to your room" : "Назад на вашу собу",
    "Message all rooms" : "Пошаљи поруку у све собе",
    "Start session" : "Започни сесију",
    "Start a call before you start a breakout room session" : "Покрените позив пре него што започнете сесију сепареа",
    "Stop session" : "Заустави сесију",
    "The message was sent to all breakout rooms" : "Порука је послата у све сепарее",
    "Send a message to all breakout rooms" : "Пошаљи поруку у све сепарее",
    "Breakout rooms are not started" : "Сепареи нису покренути",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "Позиви без позадинског механизма високих перформанси могу имати проблеме са везом и да проузрокују велико оптерећење уређаја. {linkstart}Сазнајте више{linkend}",
    "Talk setup incomplete" : "Talk подешавање није довршено",
    "Disable lobby" : "Искључи предсобље",
    "Settings for participant \"{user}\"" : "Подешавања за учесника „{user}”",
    "Participant \"{user}\"" : "Учесник „{user}”",
    "moderator" : "модератор",
    "bot" : "bot",
    "guest" : "гост",
    "Ringing …" : "Звони",
    "Call rejected" : "Позив је одбијен",
    "{time} talking …" : "{time} говори …",
    "{time} talking time" : "{time} време разговора",
    "Raised their hand" : "Подигао је руку",
    "Joined with video" : "Приступио са видеом",
    "Joined via phone" : "Приступио телефоном",
    "Joined with audio" : "Приступио са звуком",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Дужина текста мора бити краћа или једнака од {maxLength} карактера. Дужина вашег текућег текста је {charactersCount} карактера.",
    "Remove group and members" : "Уклони групу и чланове",
    "Remove team and members" : "Уклони тим и чланове",
    "Remove participant" : "Уклони учесника",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Да ли заиста желите да уклоните групу „{displayName}” и све њене чланове из овог разговора?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Да ли заиста желите да уклоните тим „{displayName}” и све његове чланове из овог разговора?",
    "Do you really want to remove {displayName} from this conversation?" : "Да ли заиста желите да уклоните {displayName} из овог разговора?",
    "Notification was sent to {displayName}" : "Обавештење је послато на име {displayName}",
    "Could not send notification to {displayName}" : "Није могло да се пошаље обавештење {displayName}",
    "Permissions granted to {displayName}" : "Одобрена је дозвола за {displayName}",
    "Could not modify permissions for {displayName}" : "Нису могле да се измене дозволе за {displayName}",
    "Permissions removed for {displayName}" : "Укинуте су дозволе за {displayName}",
    "Permissions set to default for {displayName}" : "Дозволе за {displayName} су постављене на подразумеване вредности",
    "Phone number could not be hung up" : "Није успело прекидање везе са бројем телефона",
    "Phone number could not be put on hold" : "Број телефона није могао да се постави на чекање",
    "Phone number could not be muted" : "Није успело искључивање микрофона за број телефона",
    "Phone number could not be unmuted" : "Није успело укључивање микрофона за број телефона",
    "DTMF message could not be sent" : "Није могла да се пошаље DTMF порука",
    "Phone number copied to clipboard" : "Број телефона је копиран у клипборд",
    "Phone number could not be copied" : "Није успело копирање броја телефона",
    "in the lobby" : "у предсобљу",
    "Dial out phone" : "Окрени број",
    "Hang up phone" : "Прекини везу",
    "Move back to lobby" : "Премести назад у предсобље",
    "Move to conversation" : "Премести у разговор",
    "Dial-in PIN" : "PIN за приступ",
    "Demote from moderator" : "Скини улогу модератора",
    "Promote to moderator" : "Унапреди на модератора",
    "Resend invitation" : "Поново пошаљи позивницу",
    "Send call notification" : "Пошаљи обавештење о позиву",
    "Dial out phone number" : "Окрени телефонски број",
    "Resume call for phone number" : "Настави позив за телефонски број",
    "Put phone number on hold" : "Стави телефонски број на чекање",
    "Unmute phone number" : "Укључи звук за телефонски број",
    "Mute phone number" : "Искључи микрофон за телефонски број",
    "Copy phone number" : "Копирај телефонски број",
    "Reset custom permissions" : "Ресетуј произвољне дозволе",
    "Grant all permissions" : "Одобри све дозволе",
    "Remove all permissions" : "Уклони све дозволе",
    "Also ban from this conversation" : "Такође забрани за овај разговор",
    "Internal note (reason to ban)" : "Интерна напомена (разлог забране)",
    "Remove" : "Уклони",
    "Permissions modified for {displayName}" : "Измењене су дозволе за {displayName}",
    "Add users, groups or teams" : "Додај кориснике, групе или тимове",
    "Add users or groups" : "Додај кориснике или групе",
    "Add users or teams" : "Додај кориснике или тимове",
    "Add users" : "Додај кориснике",
    "Add groups or teams" : "Додај групе или тимове",
    "Add groups" : "Додај групе",
    "Add teams" : "Додај тимове",
    "Add other sources" : "Додај остале изворе",
    "Add emails" : "Додај и-мејлове",
    "Integrations" : "Интеграције",
    "Add federated users" : "Додај федерисане кориснике",
    "Searching …" : "Тражим…",
    "Search for more users" : "Претражи још корисника",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Учеснике можете да претражујете или додате помоћу имена, и-мејла или ID здруженог облака",
    "Search or add participants" : "Претражи или додај учеснике",
    "Invitation was sent to {actorId}" : "Позивница је послата на {actorId}",
    "An error occurred while adding the participants" : "Дошло је до грешке приликом додавања учесника",
    "A new group conversation with selected participant will be created" : "Креираће се нови групни разговор са изабраним учесником",
    "Participants" : "Учесници",
    "Participants ({count})" : "Учесника ({count})",
    "Open chat" : "Отвори ћаскање",
    "You have new unread messages in the chat." : "Имате нове непрочитане поруке у чету.",
    "You have been mentioned in the chat." : "Поменути сте у чету.",
    "Search messages" : "Претражи поруке",
    "Chat" : "Ћаскање",
    "Details" : "Детаљи",
    "Shared items" : "Дељене ставке",
    "Search in {name}" : "Тражи у {name}",
    "Threads in {name}" : "Нити у {name}",
    "{actor} in {conversation}" : "{actor} у {conversation}",
    "Search messages …" : "Претражују се поруке",
    "Search options" : "Опције претраге",
    "From User" : "Од корисника",
    "Since" : "Од",
    "Until" : "До",
    "No results found" : "Нема пронађених резултата",
    "Load more results" : "Учитај још резултата",
    "Recent threads" : "Скорашње нити",
    "Projects" : "Пројекти",
    "No shared items" : "Нема дељених ставки",
    "Thread notifications" : "Обавештења низова",
    "Thread actions" : "Акције над низовима",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Веза ка разговору",
    "No open conversations found" : "Није пронађен ниједан отворени разговор",
    "Either there are no open conversations or you joined all of them." : "Или нема ниједног отвореног разговора, или учествујете у свим отвореним разговорима.",
    "Check spelling or use complete words." : "Проверите правопис или употребите комплетне речи.",
    "Search conversations or users" : "Претрага разговора или учесника",
    "Select conversation" : "Одаберите разговор",
    "Number length is not valid" : "Дужина броја није исправна",
    "Region code is not valid" : "Позивни број није исправан",
    "Number length is too short" : "Дужина броја је сувише кратка",
    "Number length is too long" : "Дужина броја је превише дугачка",
    "Number is not valid" : "Број није исправан",
    "Phone numbers" : "Бројеви телефона",
    "Display name: {name}" : "Име за приказ: {name}",
    "Edit display name" : "Уреди име за приказ",
    "Display name (required)" : "Име за приказ (обавезно)",
    "Save name" : "Сачувај име",
    "Error while setting personal setting" : "Грешка приликом постављања личног подешавања",
    "Error while saving sounds setting" : "Грешка приликом чувања поставки звукова",
    "Play sounds when participants join or leave a call" : "Пусти звукове када учесници приступе позиву или када га напусте",
    "Notification settings" : "Поставке обавештења",
    "Default language" : "Подразумевани језик",
    "Select location for attachments" : "Избор локације за прилоге",
    "Error while setting attachment folder" : "Грешка приликом постављања фолдера за прилоге",
    "Error while setting read status privacy" : "Грешка приликом постављања приватности статуса читања",
    "Error while setting typing status privacy" : "Грешка приликом постављања приватности статуса куцања",
    "Error while setting default media state" : "Грешка приликом постављања подразумеваног стања медија",
    "Privacy" : "Приватност",
    "Attachments folder" : "Фолдер са прилозима",
    "Toggle full screen" : "Укљ./Искљ. пун екран",
    "Search" : "Претрага",
    "Focus the chat input" : "Фокусирање чет уноса",
    "Unfocus the chat input to use shortcuts" : "Уклањање фокуса са чет уноса да би се користиле пречице",
    "Edit your last message" : "Уредите своју последњу поруку",
    "Shortcuts while in a call" : "Пречице током позива",
    "Camera on and off" : "Укљ./Искљ. камере",
    "Microphone on and off" : "Укљ./Искљ. миикрофона",
    "Raise or lower hand" : "Подизање или спуштање руке",
    "Push to talk or push to mute" : "Притисните да говорите или притисните да утулите",
    "Zoom-in / zoom-out a screen share" : "Увећај / Умањи дељење екрана",
    "Mouse wheel" : "Точкић миша",
    "Start call silently" : "Започни позив у тишини",
    "Start call" : "Почни позив",
    "End call" : "Заврши позив",
    "This call has just ended" : "Овај позив се управо завршио",
    "You will be able to join the call only after a moderator starts it." : "Моћи ћете да приступите позиву само када га модератор покрене.",
    "End call for everyone" : "Заврши позив за све",
    "Starting the recording" : "Почиње снимање",
    "Recording" : "Снимање",
    "The call has been running for one hour." : "Позив траје један сат.",
    "Cancel recording start" : "Откажи почетак снимања",
    "Stop recording" : "Заустави снимање",
    "Raise hand" : "Подигни руку",
    "Raise hand (R)" : "Подигни руку (R)",
    "Lower hand" : "Спуштена рука",
    "Lower hand (R)" : "Спусти руку (R)",
    "Send a reaction" : "Пошаљи реакцију",
    "React with {reaction}" : "Реагуј са {reaction}",
    "All tasks done!" : "Завршени су сви задаци!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} од %n задатка","{done} од %n задатка","{done} од %n задатака"],
    "Add participants to this call" : "Додај учеснике у овај разговор",
    "_%n participant in call_::_%n participants in call_" : ["У позиву је %n учесник","У позиву је %n учесника","У позиву је %n учесника"],
    "You are not allowed to enable screensharing" : "Није вам дозвољено да укључите дељење екрана",
    "No screensharing" : "Нема дељења екрана",
    "Screensharing options" : "Опције дељења екрана",
    "Enable screensharing" : "Укључи дељење екрана",
    "Bad sent video and screen quality." : "Лош квалитет видеа и екрана који се шаље.",
    "Bad sent screen quality." : "Лош квалитет екрана.",
    "Bad sent video quality." : "Лош квалитет видеа који се шаље.",
    "Bad sent audio, video and screen quality." : "Лош квалитет звука, видеа и екрана који се шаље.",
    "Bad sent audio and screen quality." : "Лош квалитет звука, и екрана који се шаље.",
    "Bad sent audio and video quality." : "Лош квалитет звука и видеа који се шаље.",
    "Bad sent audio quality." : "Лош квалитет звука који се шаље.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Ваша веза са интернетом или компјутер су заузети и остали учесници можда не могу да виде ваш екран. Да бисте поправили ситуацију, покушајте да искључите замућење позадине или ваш видео док делите екран.",
    "Disable background blur" : "Искључи замућење позадине",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Ваша веза са интернетом или компјутер су заузети и остали учесници можда не могу да виде ваш екран. Да бисте поправили ситуацију, покушајте да искључите ваш видео док делите екран.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Ваша веза са интернетом или компјутер су заузети и остали учесници можда не могу да виде ваш екран.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Ваша веза са интернетом или компјутер су заузети и остали учесници можда не могу да вас виде.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Ваша веза са интернетом или компјутер су заузети и остали учесници можда не могу да вас разумеју и виде. Да бисте поправили ситуацију, покушајте да искључите замућење позадине или ваш видео док делите екран.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Ваша веза са интернетом или компјутер су заузети и остали учесници можда не могу да вас разумеју и виде. Да бисте поправили ситуацију, покушајте да искључите ваш видео док делите екран.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Ваша веза са интернетом или компјутер су заузети и остали учесници можда не могу да вас разумеју и виде ваш екран. Да бисте поправили ситуацију, покушајте да искључите дељење вашег екрана.",
    "Disable screenshare" : "Искључи дељење екрана",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Ваша веза са интернетом или компјутер су заузети и остали учесници можда не могу да вас разумеју и виде. Да бисте поправили ситуацију, покушајте да искључите замућење позадине или ваш видео.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Ваша веза са интернетом или компјутер су заузети и остали учесници можда не могу да вас разумеју и виде. Да бисте поправили ситуацију, покушајте да искључите ваш видео.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Ваша веза са интернетом или компјутер су заузети и остали учесници можда не могу да вас разумеју.",
    "Screen sharing is not supported by your browser." : "Ваш веб прегледач не подржава дељење екрана.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Дељење екрана захтева да се страна учита HTTPS протоколом.",
    "Screensharing requires the page to be loaded through HTTPS." : "Дељење екрана захтева да се страна учита преко HTTPS-а.",
    "An error occurred while starting screensharing." : "Десила се грешка при покретању дељења екрана.",
    "Select virtual background" : "Изаберите виртуелну позадину",
    "Show your screen" : "Прикажите екран",
    "Stop screensharing" : "Заустави дељење екрана",
    "Mute others" : "Утули остале",
    "Start recording" : "Почни снимање",
    "Set up breakout rooms" : "Постави сепарее",
    "Download attendance list" : "Преузми листу присутних",
    "Open Calendar" : "Отвори Календар",
    "Remove participant {name}" : "Уклони учесника {name}",
    "Would you like to delete this conversation?" : "Да ли желите да обришете овај разговор?",
    "Are you sure you want to delete this conversation?" : "Да заиста желите да обришете овај разговор?",
    "Delete now" : "Обриши одмах",
    "Keep" : "Задржи",
    "Open dialpad" : "Отвори тастатуру",
    "Select a region" : "Одаберите регију",
    "Local time: {time}" : "Локално време: {time}",
    "Search …" : "Претрага ...",
    "Message without mention" : "Порука без помињања",
    "Mention myself" : "Помени мене",
    "Mention everyone" : "Помени све",
    "Select a conversation" : "Изаберите разговор",
    "Select a mode" : "Изаберите режим",
    "You do not have permissions to access this conversation." : "Немате дозволу да приступите овом разговору.",
    "Join a different conversation or start a new one." : "Приступите другом разговору, или започните нови.",
    "The conversation does not exist" : "Разговор не постоји",
    "Join a conversation or start a new one!" : "Приступите разговору или креирајте нови!",
    "Creating and joining a conversation with \"{userid}\"" : "Креира се и приступа у разговор са „{userid}”",
    "Join a conversation or start a new one" : "Придружи се разговору или започни нови",
    "Error while joining the conversation" : "Грешка приликом приступања у разговор",
    "Nextcloud URL" : "Nextcloud URL",
    "Nextcloud user" : "Nextcloud корисник",
    "User password" : "Корисничка лозинка",
    "Talk conversation" : "Talk разговори",
    "Skip TLS verification" : "Прескочи TLS потврђивање",
    "Matrix server URL" : "URL матрикс сервера",
    "User" : "Корисник",
    "Matrix channel" : "Matrix канал",
    "Mattermost server URL" : "URL Mattermost сервера",
    "Mattermost user" : "Mattermost корисник",
    "Team name" : "Назив тима",
    "Channel name" : "Назив канала",
    "Rocket.Chat server URL" : "URL Rocket.Chat сервера",
    "User name or email address" : "Корисничко име или и-мејл адреса",
    "Rocket.Chat channel" : "Rocket.Chat канал",
    "Zulip server URL" : "URL Zulip сервера ",
    "Bot user name" : "Bot корисничко име",
    "Bot API key" : "Bot API кључ",
    "Zulip channel" : "Zulip канал",
    "API token" : "API токен",
    "Slack channel" : "Slack канал",
    "Server ID or name" : "ID сервера или име",
    "Channel ID (prefixed with \"ID:\") or name" : "ID канала (са префиксом \"ID:\") или име",
    "Channel" : "Канал",
    "Login" : "Пријава",
    "Chat ID" : "ID чета",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL IRC сервера (нпр. chat.freenode.net:6667)",
    "Nickname" : "Надимак",
    "Connection password" : "Лозинка везе",
    "IRC channel" : "IRC канал",
    "Channel password" : "Лозинка канала",
    "NickServ nickname" : "NickServ надимак",
    "NickServ password" : "NickServ лозинка",
    "Use TLS" : "Користи TLS",
    "Use SASL" : "Користи SASL",
    "Tenant ID" : "ID станара",
    "Client ID" : "ID клијента",
    "Team ID" : "ID тима",
    "Thread ID" : "ID нити",
    "XMPP/Jabber server URL" : "URL XMPP/Jabber сервера",
    "MUC server URL" : "URL MUC сервера",
    "Jabber ID" : "Jabber ID",
    "Media" : "Мултимедија",
    "Polls" : "Гласања",
    "Deck cards" : "Шпил картица",
    "Voice messages" : "Гласовне поруке",
    "Locations" : "Локације",
    "Call recordings" : "Снимци позива",
    "Audio" : "Звук",
    "Show all media" : "Прикажи све медије",
    "Show all files" : "Прикажи све фајлове",
    "Show all polls" : "Прикажи сва гласања",
    "Show all deck cards" : "Прикажи све шпилове картица",
    "Show all voice messages" : "ПРикажи све гласовне поруке",
    "Show all locations" : "Прикажи све локације",
    "Show all call recordings" : "Прикажи све снимке позива",
    "Show all audio" : "Прикажи сав звук",
    "Show all other" : "Прикажи све остало",
    "Follow conversation settings" : "Прати подешавања разговора",
    "Group" : "Група",
    "Team" : "Тим",
    "You reconnected to the call" : "Поново сте се повезали на позив",
    "{actor} reconnected to the call" : "{actor} се поново придружио позиву",
    "You added {user0} and {user1}" : "Додали сте кориснике {user0} и {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Додали сте кориснике {user0}, {user1} и још %n учесника","Додали сте кориснике {user0}, {user1} и још %n учесника","Додали сте кориснике {user0}, {user1} и још %n учесника"],
    "An administrator added you and {user0}" : "Администратор је додао вас и корисника {user0}",
    "{actor} added you and {user0}" : "{actor} је додао вас и корисника {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Администратор је додао вас, корисника {user0} и још %n учесника","Администратор је додао вас, корисника {user0} и још %n учесника","Администратор је додао вас, корисника {user0} и још %n учесника"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} је додао вас, корисника {user0} и још %n учесника","{actor} је додао вас, корисника {user0} и још %n учесника","{actor} је додао вас, корисника {user0} и још %n учесника"],
    "An administrator added {user0} and {user1}" : "Администратор је додао кориснике {user0} и {user1}",
    "{actor} added {user0} and {user1}" : "{actor} је додао кориснике {user0} и {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["Администратор је додао кориснике {user0}, {user1} и још %n учесника","Администратор је додао кориснике {user0}, {user1} и још %n учесника","Администратор је додао кориснике {user0}, {user1} и још %n учесника"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} је додао кориснике {user0}, {user1} и још %n учесника","{actor} је додао кориснике {user0}, {user1} и још %n учесника","{actor} је додао кориснике {user0}, {user1} и још %n учесника"],
    "You removed {user0} and {user1}" : "Уклонили сте кориснике {user0} и {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Уклонили сте кориснике {user0}, {user1} и још %n учесника","Уклонили сте кориснике {user0}, {user1} и још %n учесника","Уклонили сте кориснике {user0}, {user1} и још %n учесника"],
    "An administrator removed you and {user0}" : "Администратор је уклонио вас и корисника {user0}",
    "{actor} removed you and {user0}" : "{actor} је уклонио вас и корисника {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Администратор је уклонио вас, корисника {user0} и још %n учесника","Администратор је уклонио вас, корисника {user0} и још %n учесника","Администратор је уклонио вас, корисника {user0} и још %n учесника"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} је уклонио вас, корисника {user0} и још %n учесника","{actor} је уклонио вас, корисника {user0} и још %n учесника","{actor} је уклонио вас, корисника {user0} и још %n учесника"],
    "An administrator removed {user0} and {user1}" : "Администратор је уклонио кориснике {user0} и {user1}",
    "{actor} removed {user0} and {user1}" : "{actor} је уклонио кориснике {user0} и {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Администратор је уклонио кориснике {user0}, {user1} и још %n учесника","Администратор је уклонио кориснике {user0}, {user1} и још %n учесника","Администратор је уклонио кориснике {user0}, {user1} и још %n учесника"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} је уклонио кориснике {user0}, {user1} и још %n учесника","{actor} је уклонио кориснике {user0}, {user1} и још %n учесника","{actor} је уклонио кориснике {user0}, {user1} и још %n учесника"],
    "You and {user0} joined the call" : "Ви и {user0} сте се придружили позиву",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Ви, {user0} и још %n учесник сте се придружили позиву","Ви, {user0} и још %n учесника сте се придружили позиву","Ви, {user0} и још %n учесника сте се придружили позиву"],
    "{user0} and {user1} joined the call" : "{user0} и {user1} су се придружили позиву",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} и још %n учесник су се придружили позиву","{user0}, {user1} и још %n учесника су се придружили позиву","{user0}, {user1} и још %n учесника су се придружили позиву"],
    "You and {user0} left the call" : "Ви и {user0} сте напустили позив",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Ви, {user0} и још %n учесник сте напустили позив","Ви, {user0} и још %n учесника сте напустили позив","Ви, {user0} и још %n учесника сте напустили позив"],
    "{user0} and {user1} left the call" : "{user0} и {user1} су напустили позив",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} и још %n учесник су напустили позив","{user0}, {user1} и још %n учесника су напустили позив","{user0}, {user1} и још %n учесника су напустили позив"],
    "You promoted {user0} and {user1} to moderators" : "Унапредили сте кориснике {user0} и {user1} у модераторе",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Унапредили сте кориснике {user0}, {user1} и још %n учесника у модераторе","Унапредили сте кориснике {user0}, {user1} и још %n учесника у модераторе","Унапредили сте кориснике {user0}, {user1} и још %n учесника у модераторе"],
    "An administrator promoted you and {user0} to moderators" : "Администратор је унапредио вас и корисника {user0} у модераторе",
    "{actor} promoted you and {user0} to moderators" : "{actor} је унапредио вас и корисника {user0} у модераторе",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Администратор је унапредио вас, корисника {user0} и још %n учесника у модераторе","Администратор је унапредио вас, корисника {user0} и још %n учесника у модераторе","Администратор је унапредио вас, корисника {user0} и још %n учесника у модераторе"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} је унапредио вас, корисника {user0} и још %n учесника у модераторе","{actor} је унапредио вас, корисника {user0} и још %n учесника у модераторе","{actor} је унапредио вас, корисника {user0} и још %n учесника у модераторе"],
    "An administrator promoted {user0} and {user1} to moderators" : "Администратор је унапредио кориснике {user0} и {user1} у модераторе",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} је унапредио кориснике {user0} и {user1} у модераторе",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Администратор је унапредио кориснике {user0}, {user1} и још %n учесника у модераторе","Администратор је унапредио кориснике {user0}, {user1} и још %n учесника у модераторе","Администратор је унапредио кориснике {user0}, {user1} и још %n учесника у модераторе"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} је унапредио кориснике {user0}, {user1} и још %n учесника у модераторе","{actor} је унапредио кориснике {user0}, {user1} и још %n учесника у модераторе","{actor} је унапредио кориснике {user0}, {user1} и још %n учесника у модераторе"],
    "You demoted {user0} and {user1} from moderators" : "Скинули сте улогу модератора за кориснике {user0} и {user1}",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Скинули сте улогу модератора за кориснике {user0}, {user1} и за још %n учесника","Скинули сте улогу модератора за кориснике {user0}, {user1} и за још %n учесника","Скинули сте улогу модератора за кориснике {user0}, {user1} и за још %n учесника"],
    "An administrator demoted you and {user0} from moderators" : "Администратор је скинуо улогу модератора за вас и за корисника {user0}",
    "{actor} demoted you and {user0} from moderators" : "{actor} је скинуо улогу модератора за вас и за корисника {user0}",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["Администратор је скинуо улогу модератора за вас, корисника {user0} и за још %n учесника","Администратор је скинуо улогу модератора за вас, корисника {user0} и за још %n учесника","Администратор је скинуо улогу модератора за вас, корисника {user0} и за још %n учесника"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} је скинуо улогу модератора за вас, корисника {user0} и за још %n учесника","{actor} је скинуо улогу модератора за вас, корисника {user0} и за још %n учесника","{actor} је скинуо улогу модератора за вас, корисника {user0} и за још %n учесника"],
    "An administrator demoted {user0} and {user1} from moderators" : "Администратор је скинуо улогу модератора за кориснике {user0} и {user1}",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} је скинуо улогу модератора за кориснике {user0} и {user1}",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["Администратор је скинуо улогу модератора за кориснике {user0}, {user1} и за још %n учесника","Администратор је скинуо улогу модератора за кориснике {user0}, {user1} и за још %n учесника","Администратор је скинуо улогу модератора за кориснике {user0}, {user1} и за још %n учесника"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} је скинуо улогу модератора за кориснике {user0}, {user1} и за још %n учесника","{actor} је скинуо улогу модератора за кориснике {user0}, {user1} и за још %n учесника","{actor} је скинуо улогу модератора за кориснике {user0}, {user1} и за још %n учесника"],
    "You:" : "Ви:",
    "You: {lastMessage}" : "Ви: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "(edited by you)" : "(ви сте уредили)",
    "(edited by a deleted user)" : "(уредио је обрисани корисник)",
    "(edited by {moderator})" : "(уредио {moderator})",
    "The recording failed. Please contact your administrator." : "Снимање није успело. Молимо вас да се обратите свом администратору.",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Покушавате да приступите разговору док имате активну сесију у другом прозору или на другом уређају. Nextcloud Talk тренутно то не подржава. Шта желите да урадите?",
    "Leave this page" : "Напусти ову страницу",
    "Join here" : "Приступи овде",
    "Deck card has been posted to {conversation}" : "Шпил карата је објављен у {conversation}",
    "An error occurred while posting deck card to conversation" : "Дошло је до грешке током објављивања шпила картица у разговор",
    "Post to a conversation" : "Објави у разговор",
    "Post to conversation" : "Објави у разговор",
    "Location has been posted to {conversation}" : "Локација је објављена у {conversation}",
    "An error occurred while posting location to conversation" : "Дошло је до грешке током објављивања локације у разговор",
    "Share to a conversation" : "Дели у разговор",
    "Share to conversation" : "Дели у разговор",
    "In conversation" : "У разговору",
    "Search in conversation: {conversation}" : "Претражи у разговору: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "Тренутно су ваши захтеви пригушени услед заштите од грубе силе.",
    "Error while clearing conversation history" : "Грешка приликом брисања историје разговора",
    "Error occurred while allowing guests" : "Дошло је до грешке током дозвољавања гостију",
    "Error occurred while disallowing guests" : "Дошло је до грешке током забране гостију",
    "Error occurred when restricting the conversation to moderator" : "Дошло је до грешке током ограничавања разговора на модератора",
    "Error occurred when opening the conversation to everyone" : "Дошло је до грешке током отварања разговора за све",
    "Conversation password has been saved" : "Сачувана је лозинка разговора",
    "Conversation password has been removed" : "Уклоњена је лозинка разговора",
    "Error occurred while saving conversation password" : "Дошло је до грешке током чувања лозинке разговора",
    "Call recording is starting." : "Покреће се снимање позива.",
    "Call recording stopped while starting." : "Снимање позива је заустављено током покретања.",
    "Call recording stopped. You will be notified once the recording is available." : "Заустављено је снимање позива. Бићете обавештени када снимак буде доступан.",
    "Conversation picture set" : "Постављена је слика разговора",
    "Conversation picture deleted" : "Обрисана је слика разговора",
    "Could not delete the conversation picture" : "Није могла да се обрише слика разговора",
    "Could not remove the automatic expiration" : "Не може да се уклони аутоматско време истека",
    "Could not post message: {errorMessage}" : "Порука није могла да се објави: {errorMessage}",
    "Participant is banned successfully" : "Учесник је успешно забрањен",
    "Error while banning the participant" : "Грешка приликом забране учесника",
    "An error occurred while fetching the participants" : "Грешка приликом дохватања учесника",
    "Could not send invitation to {actorId}" : "Није могла да се пошаље позивница на {actorId}",
    "Invitations sent" : "Позивнице су послате",
    "Error occurred when sending invitations" : "Дошло је до грешке приликом слања позивница",
    "Failed to join the conversation." : "Није успело приступање позиву.",
    "An error occurred while creating breakout rooms" : "Дошло је до грешке приликом креирања сепареа",
    "An error occurred while re-ordering the attendees" : "Дошло је до грешке приликом мењања редоследа учесника",
    "An error occurred while deleting breakout rooms" : "Дошло је до грешке приликом брисања сепареа",
    "An error occurred while starting breakout rooms" : "Дошло је до грешке приликом покретања сепареа",
    "An error occurred while stopping breakout rooms" : "Дошло је до грешке приликом заустављања сепареа",
    "An error occurred while sending a message to the breakout rooms" : "Дошло је до грешке приликом слања поруке у сепарее",
    "An error occurred while requesting assistance" : "Дошло је до грешке током захтева за помоћ",
    "An error occurred while resetting the request for assistance" : "Дошло је до грешке током уклањања захтева за помоћ",
    "An error occurred while joining breakout room" : "Дошло је до грешке приликом приступања сепареу",
    "Failed to rename the thread" : "Није успела промена имена низа",
    "Error fetching upcoming events" : "Грешка приликом преузимања предстојећих догађаја",
    "Error fetching upcoming reminders" : "Грешка приликом преузимања предстојећих подсетника",
    "An error occurred while accepting an invitation" : "Дошло је до грешке приликом прихватања позивнице",
    "An error occurred while rejecting an invitation" : "Дошло је до грешке приликом одбијања позивнице",
    "{guest} (guest)" : "{guest} (гост)",
    "Poll draft has been saved" : "Сачуван је нацрт гласања",
    "An error occurred while saving the draft" : "Дошло је до грешке током чувања нацрта",
    "An error occurred while submitting your vote" : "Дошло је до грешке приликом давања вашег гласа",
    "An error occurred while ending the poll" : "Дошло је до грешке током завршавања гласања",
    "An error occurred while deleting the poll draft" : "Дошло је до грешке током брисања нацрта гласања",
    "Poll \"{name}\" was created by {user}. Click to vote" : "Гласање „{name}” је креирао {user}. Кликните да гласате",
    "Failed to add reaction" : "Није успело додавање реакције",
    "Failed to remove reaction" : "Није успело уклањање реакције",
    "Error while uploading file \"{fileName}\"" : "Грешка приликом отпремања фајла „{fileName}”",
    "Not enough free space to upload file \"{fileName}\"" : "Нема довољно слободног простора да се отпреми „{fileName}”",
    "You are not allowed to share files" : "Није вам дозвољено да делите фајлове",
    "Error while sharing file" : "Грешка приликом дељења фајла",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Nextcloud Talk не подржава у потпуности прегледач који користите. Молимо вас да користите последњу верзију Mozilla Firefox, Microsoft Edge, Google Chrome, Opera или Apple Safari.",
    "_%n hour_::_%n hours_" : ["%n сат","%n сата","%n сати"],
    "_%n day_::_%n days_" : ["%n дан","%n дана","%n дана"],
    "_%n week_::_%n weeks_" : ["%n седмица","%n седмице","%n седмица"],
    "_In %n hour_::_In %n hours_" : ["За %n сат","За %n сата","За %n сати"],
    "_%n minute _::_%n minutes_" : ["%n минут","%n минута","%n минута"],
    "In {hours} and {minutes}" : "За {hours} и {minutes}",
    "_In %n minute_::_In %n minutes_" : ["За %n минут","За %n минута","За %n минута"],
    "Later today – {timeLocale}" : "Касније данас – {timeLocale}",
    "Tomorrow – {timeLocale}" : "Сутра – {timeLocale}",
    "This weekend – {timeLocale}" : "Овог викенда – {timeLocale}",
    "Next week – {timeLocale}" : "Наредна недеља – {timeLocale}",
    "Message link copied to clipboard" : "Линк на поруку је копиран у клипборд",
    "Conversation link copied to clipboard" : "Линк на разговор је копиран у клипборд",
    "The link could not be copied" : "Линк није могао да се копира",
    "Error while parsing a PROPFIND error" : "Грешка приликом парсирања PROPFIND грешке",
    "Sending signaling message has failed" : "Није успело слање поруке сигнализирања",
    "Lost connection to signaling server. Trying to reconnect." : "Изгубљена је веза са сервером за сигнализирање. Покушава се поновно успостављање везе.",
    "Lost connection to signaling server." : "Изгубљена је веза са сервером за сигнализирање.",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "Подешени сервер за сигнализирање мора да се ажурира како би био компатибилан са овом верзијом апликације Talk. Молимо вас да се обратите својој администрацији.",
    "Please restart the app." : "Молимо вас да поново покренете апликацију.",
    "Please reload the page." : "Поново учитајте страницу.",
    "Please try to restart the app." : "Молимо вас, покушајте поново да покренете апликацију.",
    "Please try to reload the page." : "Молимо вас, покушајте поново да учитате страницу.",
    "Do not disturb" : "Не узнемиравај",
    "Away" : "Одсутан",
    "Microphone {number}" : "Микрофон {number}",
    "Camera {number}" : "Камера {number}",
    "Speaker {number}" : "Звучник {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Изгледа да причате док сте утишани. Укључите звук да би Вас други чули",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Не може да се успостави веза са барем једним од учесника. Можда је у вашем случају потребан TURN сервер. Молимо вас да замолите свог администратора да постави један пратећи упутства у {linkstart}овој документацији{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Ово траје дуже него што је очекивано. Да ли су дозволе за мултимедију већ дозвољене (или одбијене)? Ако јесу, рестартујте веб читач, пошто аудио/видео не ради",
    "Access to microphone & camera is only possible with HTTPS" : "Приступ микрофону & камери је могућ само кроз HTTPS протокол",
    "Please move your setup to HTTPS" : "Молимо померите Вашу инсталацију на HTTPS",
    "Access to microphone & camera was denied" : "Приступ микрофону & камери одбијен",
    "WebRTC is not supported in your browser" : "WebRTC није подржан у Вашем веб читачу",
    "Please use a different browser like Firefox or Chrome" : "Користите други веб читач, као што су Фајерфокс или Хром",
    "Error while accessing microphone & camera" : "Грешка при приступању микрофону & камери",
    "%s Talk on your mobile devices" : "%s „Разговор“ на мобилним уређајима",
    "Join conversations at any time, anywhere, on any device." : "Придружите се разговорима било кад, било где, са било ког уређаја.",
    "Android app" : "Андроид апликација",
    "iOS app" : "iOS апликација",
    "__language_name__" : "Српски",
    "Webhook Demo" : "Приказ веб куке",
    "Call summary (%s)" : "Резиме позива (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Бот резимеа позива објављује поруку прегледа након позива у којој исписује све учеснике и истиче задатке",
    "Tasks" : "Задаци",
    "Notes" : "Белешке",
    "Reports" : "Извештај",
    "Decisions" : "Одлуке",
    "Agenda" : "Дневни распоред",
    "Call summary" : "Резиме позива",
    "Call summary - {title}" : "Резиме позива - {title}",
    "Talk to %s" : "Причај са %s",
    "Talk conversation for event" : "Talk разговор за догађај",
    "Client Push is installed, this improves the performance of desktop clients." : "Инсталиран је Client Push, ово унапређује перформансе десктоп клијената.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} није инсталирано, можете имати проблема са перформансама када користите десктоп клијенте.",
    "Next meeting" : "Наредни састанак",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Закажите састанак директно из календара. Talk разговор мора да се постави као локација да би се овде приказао",
    "Join conversations from remote Nextcloud servers" : "Приступи разговорима са удаљених Nextcloud сервера",
    "Your default media state has been saved" : "Сачувана је ваша поставка подразумеваног стања медија",
    "Set reminder for later today" : "Поставља подсетник касније дана",
    "Set reminder for tomorrow" : "Поставља подсетник за сутра",
    "Set reminder for this weekend" : "Поставља подсетник за овај викенд",
    "Set reminder for next week" : "Поставља подсетник за наредну недељу",
    "Generate summary" : "Генериши резиме",
    "Open poll • You voted already" : "Отворено гласање • Већ сте гласали",
    "Open poll • Click to vote" : "Отворено гласање • Кликните да гласате",
    "Poll • Ended" : "Гласање • Завршено",
    "Talk recording from {time} ({conversation})" : "Talk снимак од {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Резултати гласања • %n глас","Резултати гласања • %n гласа","Резултати гласања • %n гласова"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Отворено гласање • %n глас","Отворено гласање • %n гласа","Отворено гласање • %n гласова"],
    "Submit vote" : "Постави глас",
    "Your privacy setting has been saved" : "Ваша поставка приватности је сачувана",
    "Your personal setting has been saved" : "Сачувана су ваша лична подешавања",
    "Failed to save sounds setting" : "Није успело чување поставки звукова",
    "Sounds setting saved" : "Сачуване су поставке звукова",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Nextcloud Talk је ажуриран, не можете да започнете или да се придружите позиву.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Приступили сте разговору у другом прозору или на другом уређају. Nextcloud Talk то тренутно не подржава, па је ова сесија затворена.",
    "Nextcloud Talk was updated." : "Nextcloud talk је ажуриран.",
    "Nextcloud is in maintenance mode." : "Nextcloud је у режиму одржавања.",
    "Nextcloud Talk Federation was updated." : "Nextcloud Talk Federation је ажуриран."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
